# coding=utf-8
# *** WARNING: this file was generated by the Pulumi Terraform Bridge (tfgen) Tool. ***
# *** Do not edit by hand unless you're certain you know what you are doing! ***

import builtins
import copy
import warnings
import sys
import pulumi
import pulumi.runtime
from typing import Any, Mapping, Optional, Sequence, Union, overload
if sys.version_info >= (3, 11):
    from typing import NotRequired, TypedDict, TypeAlias
else:
    from typing_extensions import NotRequired, TypedDict, TypeAlias
from .. import _utilities

__all__ = ['CacheRuleArgs', 'CacheRule']

@pulumi.input_type
class CacheRuleArgs:
    def __init__(__self__, *,
                 site_id: pulumi.Input[builtins.int],
                 additional_cacheable_ports: Optional[pulumi.Input[builtins.str]] = None,
                 browser_cache_mode: Optional[pulumi.Input[builtins.str]] = None,
                 browser_cache_ttl: Optional[pulumi.Input[builtins.str]] = None,
                 bypass_cache: Optional[pulumi.Input[builtins.str]] = None,
                 cache_deception_armor: Optional[pulumi.Input[builtins.str]] = None,
                 cache_reserve_eligibility: Optional[pulumi.Input[builtins.str]] = None,
                 check_presence_cookie: Optional[pulumi.Input[builtins.str]] = None,
                 check_presence_header: Optional[pulumi.Input[builtins.str]] = None,
                 edge_cache_mode: Optional[pulumi.Input[builtins.str]] = None,
                 edge_cache_ttl: Optional[pulumi.Input[builtins.str]] = None,
                 edge_status_code_cache_ttl: Optional[pulumi.Input[builtins.str]] = None,
                 include_cookie: Optional[pulumi.Input[builtins.str]] = None,
                 include_header: Optional[pulumi.Input[builtins.str]] = None,
                 query_string: Optional[pulumi.Input[builtins.str]] = None,
                 query_string_mode: Optional[pulumi.Input[builtins.str]] = None,
                 rule: Optional[pulumi.Input[builtins.str]] = None,
                 rule_enable: Optional[pulumi.Input[builtins.str]] = None,
                 rule_name: Optional[pulumi.Input[builtins.str]] = None,
                 serve_stale: Optional[pulumi.Input[builtins.str]] = None,
                 site_version: Optional[pulumi.Input[builtins.int]] = None,
                 sort_query_string_for_cache: Optional[pulumi.Input[builtins.str]] = None,
                 user_device_type: Optional[pulumi.Input[builtins.str]] = None,
                 user_geo: Optional[pulumi.Input[builtins.str]] = None,
                 user_language: Optional[pulumi.Input[builtins.str]] = None):
        """
        The set of arguments for constructing a CacheRule resource.
        :param pulumi.Input[builtins.int] site_id: The site ID, which can be obtained by calling the [ListSites] API.
        :param pulumi.Input[builtins.str] additional_cacheable_ports: Enable caching on specified ports. Value range: 8880, 2052, 2082, 2086, 2095, 2053, 2083, 2087, 2096
        :param pulumi.Input[builtins.str] browser_cache_mode: Browser cache mode. Possible values:
        :param pulumi.Input[builtins.str] browser_cache_ttl: Browser cache expiration time in seconds.
        :param pulumi.Input[builtins.str] bypass_cache: Set the bypass cache mode. Possible values:
        :param pulumi.Input[builtins.str] cache_deception_armor: Cache deception protection. Used to defend against web cache deception attacks, only the cache content that passes the validation will be cached. Value range:
        :param pulumi.Input[builtins.str] cache_reserve_eligibility: Cache retention eligibility. Used to control whether user requests bypass the cache retention node when returning to the origin. Possible values:
        :param pulumi.Input[builtins.str] check_presence_cookie: When generating the cache key, check if the cookie exists. If it does, add the cookie name (case-insensitive) to the cache key. Multiple cookie names are supported, separated by spaces.
        :param pulumi.Input[builtins.str] check_presence_header: When generating the cache key, check if the header exists. If it does, add the header name (case-insensitive) to the cache key. Multiple header names are supported, separated by spaces.
        :param pulumi.Input[builtins.str] edge_cache_mode: Edge cache mode. Possible values:
        :param pulumi.Input[builtins.str] edge_cache_ttl: Edge cache expiration time in seconds.
        :param pulumi.Input[builtins.str] edge_status_code_cache_ttl: Status code cache expiration time in seconds.
        :param pulumi.Input[builtins.str] include_cookie: When generating the cache key, add the specified cookie names and their values. Multiple values are supported, separated by spaces.
        :param pulumi.Input[builtins.str] include_header: When generating the cache key, add the specified header names and their values. Multiple values are supported, separated by spaces.
        :param pulumi.Input[builtins.str] query_string: Query strings to be reserved or excluded. Multiple values are supported, separated by spaces.
        :param pulumi.Input[builtins.str] query_string_mode: The processing mode for query strings when generating the cache key. Possible values:
        :param pulumi.Input[builtins.str] rule: Rule content, using conditional expressions to match user requests. When adding global configuration, this parameter does not need to be set. There are two usage scenarios:
               - Match all incoming requests: value set to true.
               - Match specified request: Set the value to a custom expression, for example: (http.host eq \\"video.example.com\\").
        :param pulumi.Input[builtins.str] rule_enable: Rule switch. When adding global configuration, this parameter does not need to be set. Value range:
        :param pulumi.Input[builtins.str] rule_name: Rule name. When adding global configuration, this parameter does not need to be set.
        :param pulumi.Input[builtins.str] serve_stale: Serve stale cache. When enabled, the node can still respond to user requests with expired cached files when the origin server is unavailable. Value range:
        :param pulumi.Input[builtins.int] site_version: The version number of the site configuration. For sites that have enabled configuration version management, this parameter can be used to specify the effective version of the configuration site, which defaults to version 0.
        :param pulumi.Input[builtins.str] sort_query_string_for_cache: Query string sorting, disabled by default. Possible values:
        :param pulumi.Input[builtins.str] user_device_type: When generating the cache key, add the client device type. Possible values:
        :param pulumi.Input[builtins.str] user_geo: When generating the cache key, add the client's geographic location. Possible values:
        :param pulumi.Input[builtins.str] user_language: When generating cache keys, include the client's language type. Possible values:
        """
        pulumi.set(__self__, "site_id", site_id)
        if additional_cacheable_ports is not None:
            pulumi.set(__self__, "additional_cacheable_ports", additional_cacheable_ports)
        if browser_cache_mode is not None:
            pulumi.set(__self__, "browser_cache_mode", browser_cache_mode)
        if browser_cache_ttl is not None:
            pulumi.set(__self__, "browser_cache_ttl", browser_cache_ttl)
        if bypass_cache is not None:
            pulumi.set(__self__, "bypass_cache", bypass_cache)
        if cache_deception_armor is not None:
            pulumi.set(__self__, "cache_deception_armor", cache_deception_armor)
        if cache_reserve_eligibility is not None:
            pulumi.set(__self__, "cache_reserve_eligibility", cache_reserve_eligibility)
        if check_presence_cookie is not None:
            pulumi.set(__self__, "check_presence_cookie", check_presence_cookie)
        if check_presence_header is not None:
            pulumi.set(__self__, "check_presence_header", check_presence_header)
        if edge_cache_mode is not None:
            pulumi.set(__self__, "edge_cache_mode", edge_cache_mode)
        if edge_cache_ttl is not None:
            pulumi.set(__self__, "edge_cache_ttl", edge_cache_ttl)
        if edge_status_code_cache_ttl is not None:
            pulumi.set(__self__, "edge_status_code_cache_ttl", edge_status_code_cache_ttl)
        if include_cookie is not None:
            pulumi.set(__self__, "include_cookie", include_cookie)
        if include_header is not None:
            pulumi.set(__self__, "include_header", include_header)
        if query_string is not None:
            pulumi.set(__self__, "query_string", query_string)
        if query_string_mode is not None:
            pulumi.set(__self__, "query_string_mode", query_string_mode)
        if rule is not None:
            pulumi.set(__self__, "rule", rule)
        if rule_enable is not None:
            pulumi.set(__self__, "rule_enable", rule_enable)
        if rule_name is not None:
            pulumi.set(__self__, "rule_name", rule_name)
        if serve_stale is not None:
            pulumi.set(__self__, "serve_stale", serve_stale)
        if site_version is not None:
            pulumi.set(__self__, "site_version", site_version)
        if sort_query_string_for_cache is not None:
            pulumi.set(__self__, "sort_query_string_for_cache", sort_query_string_for_cache)
        if user_device_type is not None:
            pulumi.set(__self__, "user_device_type", user_device_type)
        if user_geo is not None:
            pulumi.set(__self__, "user_geo", user_geo)
        if user_language is not None:
            pulumi.set(__self__, "user_language", user_language)

    @property
    @pulumi.getter(name="siteId")
    def site_id(self) -> pulumi.Input[builtins.int]:
        """
        The site ID, which can be obtained by calling the [ListSites] API.
        """
        return pulumi.get(self, "site_id")

    @site_id.setter
    def site_id(self, value: pulumi.Input[builtins.int]):
        pulumi.set(self, "site_id", value)

    @property
    @pulumi.getter(name="additionalCacheablePorts")
    def additional_cacheable_ports(self) -> Optional[pulumi.Input[builtins.str]]:
        """
        Enable caching on specified ports. Value range: 8880, 2052, 2082, 2086, 2095, 2053, 2083, 2087, 2096
        """
        return pulumi.get(self, "additional_cacheable_ports")

    @additional_cacheable_ports.setter
    def additional_cacheable_ports(self, value: Optional[pulumi.Input[builtins.str]]):
        pulumi.set(self, "additional_cacheable_ports", value)

    @property
    @pulumi.getter(name="browserCacheMode")
    def browser_cache_mode(self) -> Optional[pulumi.Input[builtins.str]]:
        """
        Browser cache mode. Possible values:
        """
        return pulumi.get(self, "browser_cache_mode")

    @browser_cache_mode.setter
    def browser_cache_mode(self, value: Optional[pulumi.Input[builtins.str]]):
        pulumi.set(self, "browser_cache_mode", value)

    @property
    @pulumi.getter(name="browserCacheTtl")
    def browser_cache_ttl(self) -> Optional[pulumi.Input[builtins.str]]:
        """
        Browser cache expiration time in seconds.
        """
        return pulumi.get(self, "browser_cache_ttl")

    @browser_cache_ttl.setter
    def browser_cache_ttl(self, value: Optional[pulumi.Input[builtins.str]]):
        pulumi.set(self, "browser_cache_ttl", value)

    @property
    @pulumi.getter(name="bypassCache")
    def bypass_cache(self) -> Optional[pulumi.Input[builtins.str]]:
        """
        Set the bypass cache mode. Possible values:
        """
        return pulumi.get(self, "bypass_cache")

    @bypass_cache.setter
    def bypass_cache(self, value: Optional[pulumi.Input[builtins.str]]):
        pulumi.set(self, "bypass_cache", value)

    @property
    @pulumi.getter(name="cacheDeceptionArmor")
    def cache_deception_armor(self) -> Optional[pulumi.Input[builtins.str]]:
        """
        Cache deception protection. Used to defend against web cache deception attacks, only the cache content that passes the validation will be cached. Value range:
        """
        return pulumi.get(self, "cache_deception_armor")

    @cache_deception_armor.setter
    def cache_deception_armor(self, value: Optional[pulumi.Input[builtins.str]]):
        pulumi.set(self, "cache_deception_armor", value)

    @property
    @pulumi.getter(name="cacheReserveEligibility")
    def cache_reserve_eligibility(self) -> Optional[pulumi.Input[builtins.str]]:
        """
        Cache retention eligibility. Used to control whether user requests bypass the cache retention node when returning to the origin. Possible values:
        """
        return pulumi.get(self, "cache_reserve_eligibility")

    @cache_reserve_eligibility.setter
    def cache_reserve_eligibility(self, value: Optional[pulumi.Input[builtins.str]]):
        pulumi.set(self, "cache_reserve_eligibility", value)

    @property
    @pulumi.getter(name="checkPresenceCookie")
    def check_presence_cookie(self) -> Optional[pulumi.Input[builtins.str]]:
        """
        When generating the cache key, check if the cookie exists. If it does, add the cookie name (case-insensitive) to the cache key. Multiple cookie names are supported, separated by spaces.
        """
        return pulumi.get(self, "check_presence_cookie")

    @check_presence_cookie.setter
    def check_presence_cookie(self, value: Optional[pulumi.Input[builtins.str]]):
        pulumi.set(self, "check_presence_cookie", value)

    @property
    @pulumi.getter(name="checkPresenceHeader")
    def check_presence_header(self) -> Optional[pulumi.Input[builtins.str]]:
        """
        When generating the cache key, check if the header exists. If it does, add the header name (case-insensitive) to the cache key. Multiple header names are supported, separated by spaces.
        """
        return pulumi.get(self, "check_presence_header")

    @check_presence_header.setter
    def check_presence_header(self, value: Optional[pulumi.Input[builtins.str]]):
        pulumi.set(self, "check_presence_header", value)

    @property
    @pulumi.getter(name="edgeCacheMode")
    def edge_cache_mode(self) -> Optional[pulumi.Input[builtins.str]]:
        """
        Edge cache mode. Possible values:
        """
        return pulumi.get(self, "edge_cache_mode")

    @edge_cache_mode.setter
    def edge_cache_mode(self, value: Optional[pulumi.Input[builtins.str]]):
        pulumi.set(self, "edge_cache_mode", value)

    @property
    @pulumi.getter(name="edgeCacheTtl")
    def edge_cache_ttl(self) -> Optional[pulumi.Input[builtins.str]]:
        """
        Edge cache expiration time in seconds.
        """
        return pulumi.get(self, "edge_cache_ttl")

    @edge_cache_ttl.setter
    def edge_cache_ttl(self, value: Optional[pulumi.Input[builtins.str]]):
        pulumi.set(self, "edge_cache_ttl", value)

    @property
    @pulumi.getter(name="edgeStatusCodeCacheTtl")
    def edge_status_code_cache_ttl(self) -> Optional[pulumi.Input[builtins.str]]:
        """
        Status code cache expiration time in seconds.
        """
        return pulumi.get(self, "edge_status_code_cache_ttl")

    @edge_status_code_cache_ttl.setter
    def edge_status_code_cache_ttl(self, value: Optional[pulumi.Input[builtins.str]]):
        pulumi.set(self, "edge_status_code_cache_ttl", value)

    @property
    @pulumi.getter(name="includeCookie")
    def include_cookie(self) -> Optional[pulumi.Input[builtins.str]]:
        """
        When generating the cache key, add the specified cookie names and their values. Multiple values are supported, separated by spaces.
        """
        return pulumi.get(self, "include_cookie")

    @include_cookie.setter
    def include_cookie(self, value: Optional[pulumi.Input[builtins.str]]):
        pulumi.set(self, "include_cookie", value)

    @property
    @pulumi.getter(name="includeHeader")
    def include_header(self) -> Optional[pulumi.Input[builtins.str]]:
        """
        When generating the cache key, add the specified header names and their values. Multiple values are supported, separated by spaces.
        """
        return pulumi.get(self, "include_header")

    @include_header.setter
    def include_header(self, value: Optional[pulumi.Input[builtins.str]]):
        pulumi.set(self, "include_header", value)

    @property
    @pulumi.getter(name="queryString")
    def query_string(self) -> Optional[pulumi.Input[builtins.str]]:
        """
        Query strings to be reserved or excluded. Multiple values are supported, separated by spaces.
        """
        return pulumi.get(self, "query_string")

    @query_string.setter
    def query_string(self, value: Optional[pulumi.Input[builtins.str]]):
        pulumi.set(self, "query_string", value)

    @property
    @pulumi.getter(name="queryStringMode")
    def query_string_mode(self) -> Optional[pulumi.Input[builtins.str]]:
        """
        The processing mode for query strings when generating the cache key. Possible values:
        """
        return pulumi.get(self, "query_string_mode")

    @query_string_mode.setter
    def query_string_mode(self, value: Optional[pulumi.Input[builtins.str]]):
        pulumi.set(self, "query_string_mode", value)

    @property
    @pulumi.getter
    def rule(self) -> Optional[pulumi.Input[builtins.str]]:
        """
        Rule content, using conditional expressions to match user requests. When adding global configuration, this parameter does not need to be set. There are two usage scenarios:
        - Match all incoming requests: value set to true.
        - Match specified request: Set the value to a custom expression, for example: (http.host eq \\"video.example.com\\").
        """
        return pulumi.get(self, "rule")

    @rule.setter
    def rule(self, value: Optional[pulumi.Input[builtins.str]]):
        pulumi.set(self, "rule", value)

    @property
    @pulumi.getter(name="ruleEnable")
    def rule_enable(self) -> Optional[pulumi.Input[builtins.str]]:
        """
        Rule switch. When adding global configuration, this parameter does not need to be set. Value range:
        """
        return pulumi.get(self, "rule_enable")

    @rule_enable.setter
    def rule_enable(self, value: Optional[pulumi.Input[builtins.str]]):
        pulumi.set(self, "rule_enable", value)

    @property
    @pulumi.getter(name="ruleName")
    def rule_name(self) -> Optional[pulumi.Input[builtins.str]]:
        """
        Rule name. When adding global configuration, this parameter does not need to be set.
        """
        return pulumi.get(self, "rule_name")

    @rule_name.setter
    def rule_name(self, value: Optional[pulumi.Input[builtins.str]]):
        pulumi.set(self, "rule_name", value)

    @property
    @pulumi.getter(name="serveStale")
    def serve_stale(self) -> Optional[pulumi.Input[builtins.str]]:
        """
        Serve stale cache. When enabled, the node can still respond to user requests with expired cached files when the origin server is unavailable. Value range:
        """
        return pulumi.get(self, "serve_stale")

    @serve_stale.setter
    def serve_stale(self, value: Optional[pulumi.Input[builtins.str]]):
        pulumi.set(self, "serve_stale", value)

    @property
    @pulumi.getter(name="siteVersion")
    def site_version(self) -> Optional[pulumi.Input[builtins.int]]:
        """
        The version number of the site configuration. For sites that have enabled configuration version management, this parameter can be used to specify the effective version of the configuration site, which defaults to version 0.
        """
        return pulumi.get(self, "site_version")

    @site_version.setter
    def site_version(self, value: Optional[pulumi.Input[builtins.int]]):
        pulumi.set(self, "site_version", value)

    @property
    @pulumi.getter(name="sortQueryStringForCache")
    def sort_query_string_for_cache(self) -> Optional[pulumi.Input[builtins.str]]:
        """
        Query string sorting, disabled by default. Possible values:
        """
        return pulumi.get(self, "sort_query_string_for_cache")

    @sort_query_string_for_cache.setter
    def sort_query_string_for_cache(self, value: Optional[pulumi.Input[builtins.str]]):
        pulumi.set(self, "sort_query_string_for_cache", value)

    @property
    @pulumi.getter(name="userDeviceType")
    def user_device_type(self) -> Optional[pulumi.Input[builtins.str]]:
        """
        When generating the cache key, add the client device type. Possible values:
        """
        return pulumi.get(self, "user_device_type")

    @user_device_type.setter
    def user_device_type(self, value: Optional[pulumi.Input[builtins.str]]):
        pulumi.set(self, "user_device_type", value)

    @property
    @pulumi.getter(name="userGeo")
    def user_geo(self) -> Optional[pulumi.Input[builtins.str]]:
        """
        When generating the cache key, add the client's geographic location. Possible values:
        """
        return pulumi.get(self, "user_geo")

    @user_geo.setter
    def user_geo(self, value: Optional[pulumi.Input[builtins.str]]):
        pulumi.set(self, "user_geo", value)

    @property
    @pulumi.getter(name="userLanguage")
    def user_language(self) -> Optional[pulumi.Input[builtins.str]]:
        """
        When generating cache keys, include the client's language type. Possible values:
        """
        return pulumi.get(self, "user_language")

    @user_language.setter
    def user_language(self, value: Optional[pulumi.Input[builtins.str]]):
        pulumi.set(self, "user_language", value)


@pulumi.input_type
class _CacheRuleState:
    def __init__(__self__, *,
                 additional_cacheable_ports: Optional[pulumi.Input[builtins.str]] = None,
                 browser_cache_mode: Optional[pulumi.Input[builtins.str]] = None,
                 browser_cache_ttl: Optional[pulumi.Input[builtins.str]] = None,
                 bypass_cache: Optional[pulumi.Input[builtins.str]] = None,
                 cache_deception_armor: Optional[pulumi.Input[builtins.str]] = None,
                 cache_reserve_eligibility: Optional[pulumi.Input[builtins.str]] = None,
                 cache_rule_id: Optional[pulumi.Input[builtins.int]] = None,
                 check_presence_cookie: Optional[pulumi.Input[builtins.str]] = None,
                 check_presence_header: Optional[pulumi.Input[builtins.str]] = None,
                 edge_cache_mode: Optional[pulumi.Input[builtins.str]] = None,
                 edge_cache_ttl: Optional[pulumi.Input[builtins.str]] = None,
                 edge_status_code_cache_ttl: Optional[pulumi.Input[builtins.str]] = None,
                 include_cookie: Optional[pulumi.Input[builtins.str]] = None,
                 include_header: Optional[pulumi.Input[builtins.str]] = None,
                 query_string: Optional[pulumi.Input[builtins.str]] = None,
                 query_string_mode: Optional[pulumi.Input[builtins.str]] = None,
                 rule: Optional[pulumi.Input[builtins.str]] = None,
                 rule_enable: Optional[pulumi.Input[builtins.str]] = None,
                 rule_name: Optional[pulumi.Input[builtins.str]] = None,
                 serve_stale: Optional[pulumi.Input[builtins.str]] = None,
                 site_id: Optional[pulumi.Input[builtins.int]] = None,
                 site_version: Optional[pulumi.Input[builtins.int]] = None,
                 sort_query_string_for_cache: Optional[pulumi.Input[builtins.str]] = None,
                 user_device_type: Optional[pulumi.Input[builtins.str]] = None,
                 user_geo: Optional[pulumi.Input[builtins.str]] = None,
                 user_language: Optional[pulumi.Input[builtins.str]] = None):
        """
        Input properties used for looking up and filtering CacheRule resources.
        :param pulumi.Input[builtins.str] additional_cacheable_ports: Enable caching on specified ports. Value range: 8880, 2052, 2082, 2086, 2095, 2053, 2083, 2087, 2096
        :param pulumi.Input[builtins.str] browser_cache_mode: Browser cache mode. Possible values:
        :param pulumi.Input[builtins.str] browser_cache_ttl: Browser cache expiration time in seconds.
        :param pulumi.Input[builtins.str] bypass_cache: Set the bypass cache mode. Possible values:
        :param pulumi.Input[builtins.str] cache_deception_armor: Cache deception protection. Used to defend against web cache deception attacks, only the cache content that passes the validation will be cached. Value range:
        :param pulumi.Input[builtins.str] cache_reserve_eligibility: Cache retention eligibility. Used to control whether user requests bypass the cache retention node when returning to the origin. Possible values:
        :param pulumi.Input[builtins.int] cache_rule_id: Cache Rule Id.
        :param pulumi.Input[builtins.str] check_presence_cookie: When generating the cache key, check if the cookie exists. If it does, add the cookie name (case-insensitive) to the cache key. Multiple cookie names are supported, separated by spaces.
        :param pulumi.Input[builtins.str] check_presence_header: When generating the cache key, check if the header exists. If it does, add the header name (case-insensitive) to the cache key. Multiple header names are supported, separated by spaces.
        :param pulumi.Input[builtins.str] edge_cache_mode: Edge cache mode. Possible values:
        :param pulumi.Input[builtins.str] edge_cache_ttl: Edge cache expiration time in seconds.
        :param pulumi.Input[builtins.str] edge_status_code_cache_ttl: Status code cache expiration time in seconds.
        :param pulumi.Input[builtins.str] include_cookie: When generating the cache key, add the specified cookie names and their values. Multiple values are supported, separated by spaces.
        :param pulumi.Input[builtins.str] include_header: When generating the cache key, add the specified header names and their values. Multiple values are supported, separated by spaces.
        :param pulumi.Input[builtins.str] query_string: Query strings to be reserved or excluded. Multiple values are supported, separated by spaces.
        :param pulumi.Input[builtins.str] query_string_mode: The processing mode for query strings when generating the cache key. Possible values:
        :param pulumi.Input[builtins.str] rule: Rule content, using conditional expressions to match user requests. When adding global configuration, this parameter does not need to be set. There are two usage scenarios:
               - Match all incoming requests: value set to true.
               - Match specified request: Set the value to a custom expression, for example: (http.host eq \\"video.example.com\\").
        :param pulumi.Input[builtins.str] rule_enable: Rule switch. When adding global configuration, this parameter does not need to be set. Value range:
        :param pulumi.Input[builtins.str] rule_name: Rule name. When adding global configuration, this parameter does not need to be set.
        :param pulumi.Input[builtins.str] serve_stale: Serve stale cache. When enabled, the node can still respond to user requests with expired cached files when the origin server is unavailable. Value range:
        :param pulumi.Input[builtins.int] site_id: The site ID, which can be obtained by calling the [ListSites] API.
        :param pulumi.Input[builtins.int] site_version: The version number of the site configuration. For sites that have enabled configuration version management, this parameter can be used to specify the effective version of the configuration site, which defaults to version 0.
        :param pulumi.Input[builtins.str] sort_query_string_for_cache: Query string sorting, disabled by default. Possible values:
        :param pulumi.Input[builtins.str] user_device_type: When generating the cache key, add the client device type. Possible values:
        :param pulumi.Input[builtins.str] user_geo: When generating the cache key, add the client's geographic location. Possible values:
        :param pulumi.Input[builtins.str] user_language: When generating cache keys, include the client's language type. Possible values:
        """
        if additional_cacheable_ports is not None:
            pulumi.set(__self__, "additional_cacheable_ports", additional_cacheable_ports)
        if browser_cache_mode is not None:
            pulumi.set(__self__, "browser_cache_mode", browser_cache_mode)
        if browser_cache_ttl is not None:
            pulumi.set(__self__, "browser_cache_ttl", browser_cache_ttl)
        if bypass_cache is not None:
            pulumi.set(__self__, "bypass_cache", bypass_cache)
        if cache_deception_armor is not None:
            pulumi.set(__self__, "cache_deception_armor", cache_deception_armor)
        if cache_reserve_eligibility is not None:
            pulumi.set(__self__, "cache_reserve_eligibility", cache_reserve_eligibility)
        if cache_rule_id is not None:
            pulumi.set(__self__, "cache_rule_id", cache_rule_id)
        if check_presence_cookie is not None:
            pulumi.set(__self__, "check_presence_cookie", check_presence_cookie)
        if check_presence_header is not None:
            pulumi.set(__self__, "check_presence_header", check_presence_header)
        if edge_cache_mode is not None:
            pulumi.set(__self__, "edge_cache_mode", edge_cache_mode)
        if edge_cache_ttl is not None:
            pulumi.set(__self__, "edge_cache_ttl", edge_cache_ttl)
        if edge_status_code_cache_ttl is not None:
            pulumi.set(__self__, "edge_status_code_cache_ttl", edge_status_code_cache_ttl)
        if include_cookie is not None:
            pulumi.set(__self__, "include_cookie", include_cookie)
        if include_header is not None:
            pulumi.set(__self__, "include_header", include_header)
        if query_string is not None:
            pulumi.set(__self__, "query_string", query_string)
        if query_string_mode is not None:
            pulumi.set(__self__, "query_string_mode", query_string_mode)
        if rule is not None:
            pulumi.set(__self__, "rule", rule)
        if rule_enable is not None:
            pulumi.set(__self__, "rule_enable", rule_enable)
        if rule_name is not None:
            pulumi.set(__self__, "rule_name", rule_name)
        if serve_stale is not None:
            pulumi.set(__self__, "serve_stale", serve_stale)
        if site_id is not None:
            pulumi.set(__self__, "site_id", site_id)
        if site_version is not None:
            pulumi.set(__self__, "site_version", site_version)
        if sort_query_string_for_cache is not None:
            pulumi.set(__self__, "sort_query_string_for_cache", sort_query_string_for_cache)
        if user_device_type is not None:
            pulumi.set(__self__, "user_device_type", user_device_type)
        if user_geo is not None:
            pulumi.set(__self__, "user_geo", user_geo)
        if user_language is not None:
            pulumi.set(__self__, "user_language", user_language)

    @property
    @pulumi.getter(name="additionalCacheablePorts")
    def additional_cacheable_ports(self) -> Optional[pulumi.Input[builtins.str]]:
        """
        Enable caching on specified ports. Value range: 8880, 2052, 2082, 2086, 2095, 2053, 2083, 2087, 2096
        """
        return pulumi.get(self, "additional_cacheable_ports")

    @additional_cacheable_ports.setter
    def additional_cacheable_ports(self, value: Optional[pulumi.Input[builtins.str]]):
        pulumi.set(self, "additional_cacheable_ports", value)

    @property
    @pulumi.getter(name="browserCacheMode")
    def browser_cache_mode(self) -> Optional[pulumi.Input[builtins.str]]:
        """
        Browser cache mode. Possible values:
        """
        return pulumi.get(self, "browser_cache_mode")

    @browser_cache_mode.setter
    def browser_cache_mode(self, value: Optional[pulumi.Input[builtins.str]]):
        pulumi.set(self, "browser_cache_mode", value)

    @property
    @pulumi.getter(name="browserCacheTtl")
    def browser_cache_ttl(self) -> Optional[pulumi.Input[builtins.str]]:
        """
        Browser cache expiration time in seconds.
        """
        return pulumi.get(self, "browser_cache_ttl")

    @browser_cache_ttl.setter
    def browser_cache_ttl(self, value: Optional[pulumi.Input[builtins.str]]):
        pulumi.set(self, "browser_cache_ttl", value)

    @property
    @pulumi.getter(name="bypassCache")
    def bypass_cache(self) -> Optional[pulumi.Input[builtins.str]]:
        """
        Set the bypass cache mode. Possible values:
        """
        return pulumi.get(self, "bypass_cache")

    @bypass_cache.setter
    def bypass_cache(self, value: Optional[pulumi.Input[builtins.str]]):
        pulumi.set(self, "bypass_cache", value)

    @property
    @pulumi.getter(name="cacheDeceptionArmor")
    def cache_deception_armor(self) -> Optional[pulumi.Input[builtins.str]]:
        """
        Cache deception protection. Used to defend against web cache deception attacks, only the cache content that passes the validation will be cached. Value range:
        """
        return pulumi.get(self, "cache_deception_armor")

    @cache_deception_armor.setter
    def cache_deception_armor(self, value: Optional[pulumi.Input[builtins.str]]):
        pulumi.set(self, "cache_deception_armor", value)

    @property
    @pulumi.getter(name="cacheReserveEligibility")
    def cache_reserve_eligibility(self) -> Optional[pulumi.Input[builtins.str]]:
        """
        Cache retention eligibility. Used to control whether user requests bypass the cache retention node when returning to the origin. Possible values:
        """
        return pulumi.get(self, "cache_reserve_eligibility")

    @cache_reserve_eligibility.setter
    def cache_reserve_eligibility(self, value: Optional[pulumi.Input[builtins.str]]):
        pulumi.set(self, "cache_reserve_eligibility", value)

    @property
    @pulumi.getter(name="cacheRuleId")
    def cache_rule_id(self) -> Optional[pulumi.Input[builtins.int]]:
        """
        Cache Rule Id.
        """
        return pulumi.get(self, "cache_rule_id")

    @cache_rule_id.setter
    def cache_rule_id(self, value: Optional[pulumi.Input[builtins.int]]):
        pulumi.set(self, "cache_rule_id", value)

    @property
    @pulumi.getter(name="checkPresenceCookie")
    def check_presence_cookie(self) -> Optional[pulumi.Input[builtins.str]]:
        """
        When generating the cache key, check if the cookie exists. If it does, add the cookie name (case-insensitive) to the cache key. Multiple cookie names are supported, separated by spaces.
        """
        return pulumi.get(self, "check_presence_cookie")

    @check_presence_cookie.setter
    def check_presence_cookie(self, value: Optional[pulumi.Input[builtins.str]]):
        pulumi.set(self, "check_presence_cookie", value)

    @property
    @pulumi.getter(name="checkPresenceHeader")
    def check_presence_header(self) -> Optional[pulumi.Input[builtins.str]]:
        """
        When generating the cache key, check if the header exists. If it does, add the header name (case-insensitive) to the cache key. Multiple header names are supported, separated by spaces.
        """
        return pulumi.get(self, "check_presence_header")

    @check_presence_header.setter
    def check_presence_header(self, value: Optional[pulumi.Input[builtins.str]]):
        pulumi.set(self, "check_presence_header", value)

    @property
    @pulumi.getter(name="edgeCacheMode")
    def edge_cache_mode(self) -> Optional[pulumi.Input[builtins.str]]:
        """
        Edge cache mode. Possible values:
        """
        return pulumi.get(self, "edge_cache_mode")

    @edge_cache_mode.setter
    def edge_cache_mode(self, value: Optional[pulumi.Input[builtins.str]]):
        pulumi.set(self, "edge_cache_mode", value)

    @property
    @pulumi.getter(name="edgeCacheTtl")
    def edge_cache_ttl(self) -> Optional[pulumi.Input[builtins.str]]:
        """
        Edge cache expiration time in seconds.
        """
        return pulumi.get(self, "edge_cache_ttl")

    @edge_cache_ttl.setter
    def edge_cache_ttl(self, value: Optional[pulumi.Input[builtins.str]]):
        pulumi.set(self, "edge_cache_ttl", value)

    @property
    @pulumi.getter(name="edgeStatusCodeCacheTtl")
    def edge_status_code_cache_ttl(self) -> Optional[pulumi.Input[builtins.str]]:
        """
        Status code cache expiration time in seconds.
        """
        return pulumi.get(self, "edge_status_code_cache_ttl")

    @edge_status_code_cache_ttl.setter
    def edge_status_code_cache_ttl(self, value: Optional[pulumi.Input[builtins.str]]):
        pulumi.set(self, "edge_status_code_cache_ttl", value)

    @property
    @pulumi.getter(name="includeCookie")
    def include_cookie(self) -> Optional[pulumi.Input[builtins.str]]:
        """
        When generating the cache key, add the specified cookie names and their values. Multiple values are supported, separated by spaces.
        """
        return pulumi.get(self, "include_cookie")

    @include_cookie.setter
    def include_cookie(self, value: Optional[pulumi.Input[builtins.str]]):
        pulumi.set(self, "include_cookie", value)

    @property
    @pulumi.getter(name="includeHeader")
    def include_header(self) -> Optional[pulumi.Input[builtins.str]]:
        """
        When generating the cache key, add the specified header names and their values. Multiple values are supported, separated by spaces.
        """
        return pulumi.get(self, "include_header")

    @include_header.setter
    def include_header(self, value: Optional[pulumi.Input[builtins.str]]):
        pulumi.set(self, "include_header", value)

    @property
    @pulumi.getter(name="queryString")
    def query_string(self) -> Optional[pulumi.Input[builtins.str]]:
        """
        Query strings to be reserved or excluded. Multiple values are supported, separated by spaces.
        """
        return pulumi.get(self, "query_string")

    @query_string.setter
    def query_string(self, value: Optional[pulumi.Input[builtins.str]]):
        pulumi.set(self, "query_string", value)

    @property
    @pulumi.getter(name="queryStringMode")
    def query_string_mode(self) -> Optional[pulumi.Input[builtins.str]]:
        """
        The processing mode for query strings when generating the cache key. Possible values:
        """
        return pulumi.get(self, "query_string_mode")

    @query_string_mode.setter
    def query_string_mode(self, value: Optional[pulumi.Input[builtins.str]]):
        pulumi.set(self, "query_string_mode", value)

    @property
    @pulumi.getter
    def rule(self) -> Optional[pulumi.Input[builtins.str]]:
        """
        Rule content, using conditional expressions to match user requests. When adding global configuration, this parameter does not need to be set. There are two usage scenarios:
        - Match all incoming requests: value set to true.
        - Match specified request: Set the value to a custom expression, for example: (http.host eq \\"video.example.com\\").
        """
        return pulumi.get(self, "rule")

    @rule.setter
    def rule(self, value: Optional[pulumi.Input[builtins.str]]):
        pulumi.set(self, "rule", value)

    @property
    @pulumi.getter(name="ruleEnable")
    def rule_enable(self) -> Optional[pulumi.Input[builtins.str]]:
        """
        Rule switch. When adding global configuration, this parameter does not need to be set. Value range:
        """
        return pulumi.get(self, "rule_enable")

    @rule_enable.setter
    def rule_enable(self, value: Optional[pulumi.Input[builtins.str]]):
        pulumi.set(self, "rule_enable", value)

    @property
    @pulumi.getter(name="ruleName")
    def rule_name(self) -> Optional[pulumi.Input[builtins.str]]:
        """
        Rule name. When adding global configuration, this parameter does not need to be set.
        """
        return pulumi.get(self, "rule_name")

    @rule_name.setter
    def rule_name(self, value: Optional[pulumi.Input[builtins.str]]):
        pulumi.set(self, "rule_name", value)

    @property
    @pulumi.getter(name="serveStale")
    def serve_stale(self) -> Optional[pulumi.Input[builtins.str]]:
        """
        Serve stale cache. When enabled, the node can still respond to user requests with expired cached files when the origin server is unavailable. Value range:
        """
        return pulumi.get(self, "serve_stale")

    @serve_stale.setter
    def serve_stale(self, value: Optional[pulumi.Input[builtins.str]]):
        pulumi.set(self, "serve_stale", value)

    @property
    @pulumi.getter(name="siteId")
    def site_id(self) -> Optional[pulumi.Input[builtins.int]]:
        """
        The site ID, which can be obtained by calling the [ListSites] API.
        """
        return pulumi.get(self, "site_id")

    @site_id.setter
    def site_id(self, value: Optional[pulumi.Input[builtins.int]]):
        pulumi.set(self, "site_id", value)

    @property
    @pulumi.getter(name="siteVersion")
    def site_version(self) -> Optional[pulumi.Input[builtins.int]]:
        """
        The version number of the site configuration. For sites that have enabled configuration version management, this parameter can be used to specify the effective version of the configuration site, which defaults to version 0.
        """
        return pulumi.get(self, "site_version")

    @site_version.setter
    def site_version(self, value: Optional[pulumi.Input[builtins.int]]):
        pulumi.set(self, "site_version", value)

    @property
    @pulumi.getter(name="sortQueryStringForCache")
    def sort_query_string_for_cache(self) -> Optional[pulumi.Input[builtins.str]]:
        """
        Query string sorting, disabled by default. Possible values:
        """
        return pulumi.get(self, "sort_query_string_for_cache")

    @sort_query_string_for_cache.setter
    def sort_query_string_for_cache(self, value: Optional[pulumi.Input[builtins.str]]):
        pulumi.set(self, "sort_query_string_for_cache", value)

    @property
    @pulumi.getter(name="userDeviceType")
    def user_device_type(self) -> Optional[pulumi.Input[builtins.str]]:
        """
        When generating the cache key, add the client device type. Possible values:
        """
        return pulumi.get(self, "user_device_type")

    @user_device_type.setter
    def user_device_type(self, value: Optional[pulumi.Input[builtins.str]]):
        pulumi.set(self, "user_device_type", value)

    @property
    @pulumi.getter(name="userGeo")
    def user_geo(self) -> Optional[pulumi.Input[builtins.str]]:
        """
        When generating the cache key, add the client's geographic location. Possible values:
        """
        return pulumi.get(self, "user_geo")

    @user_geo.setter
    def user_geo(self, value: Optional[pulumi.Input[builtins.str]]):
        pulumi.set(self, "user_geo", value)

    @property
    @pulumi.getter(name="userLanguage")
    def user_language(self) -> Optional[pulumi.Input[builtins.str]]:
        """
        When generating cache keys, include the client's language type. Possible values:
        """
        return pulumi.get(self, "user_language")

    @user_language.setter
    def user_language(self, value: Optional[pulumi.Input[builtins.str]]):
        pulumi.set(self, "user_language", value)


@pulumi.type_token("alicloud:esa/cacheRule:CacheRule")
class CacheRule(pulumi.CustomResource):
    @overload
    def __init__(__self__,
                 resource_name: str,
                 opts: Optional[pulumi.ResourceOptions] = None,
                 additional_cacheable_ports: Optional[pulumi.Input[builtins.str]] = None,
                 browser_cache_mode: Optional[pulumi.Input[builtins.str]] = None,
                 browser_cache_ttl: Optional[pulumi.Input[builtins.str]] = None,
                 bypass_cache: Optional[pulumi.Input[builtins.str]] = None,
                 cache_deception_armor: Optional[pulumi.Input[builtins.str]] = None,
                 cache_reserve_eligibility: Optional[pulumi.Input[builtins.str]] = None,
                 check_presence_cookie: Optional[pulumi.Input[builtins.str]] = None,
                 check_presence_header: Optional[pulumi.Input[builtins.str]] = None,
                 edge_cache_mode: Optional[pulumi.Input[builtins.str]] = None,
                 edge_cache_ttl: Optional[pulumi.Input[builtins.str]] = None,
                 edge_status_code_cache_ttl: Optional[pulumi.Input[builtins.str]] = None,
                 include_cookie: Optional[pulumi.Input[builtins.str]] = None,
                 include_header: Optional[pulumi.Input[builtins.str]] = None,
                 query_string: Optional[pulumi.Input[builtins.str]] = None,
                 query_string_mode: Optional[pulumi.Input[builtins.str]] = None,
                 rule: Optional[pulumi.Input[builtins.str]] = None,
                 rule_enable: Optional[pulumi.Input[builtins.str]] = None,
                 rule_name: Optional[pulumi.Input[builtins.str]] = None,
                 serve_stale: Optional[pulumi.Input[builtins.str]] = None,
                 site_id: Optional[pulumi.Input[builtins.int]] = None,
                 site_version: Optional[pulumi.Input[builtins.int]] = None,
                 sort_query_string_for_cache: Optional[pulumi.Input[builtins.str]] = None,
                 user_device_type: Optional[pulumi.Input[builtins.str]] = None,
                 user_geo: Optional[pulumi.Input[builtins.str]] = None,
                 user_language: Optional[pulumi.Input[builtins.str]] = None,
                 __props__=None):
        """
        Provides a ESA Cache Rule resource.

        For information about ESA Cache Rule and how to use it, see [What is Cache Rule](https://next.api.alibabacloud.com/document/ESA/2024-09-10/CreateCacheRule).

        > **NOTE:** Available since v1.244.0.

        ## Example Usage

        Basic Usage

        ```python
        import pulumi
        import pulumi_alicloud as alicloud

        default = alicloud.esa.get_sites(plan_subscribe_type="enterpriseplan")
        default_cache_rule = alicloud.esa.CacheRule("default",
            user_device_type="off",
            browser_cache_mode="no_cache",
            user_language="off",
            check_presence_header="headername",
            include_cookie="cookie_exapmle",
            edge_cache_mode="follow_origin",
            additional_cacheable_ports="2053",
            rule_name="rule_example",
            edge_status_code_cache_ttl="300",
            browser_cache_ttl="300",
            query_string="example",
            user_geo="off",
            sort_query_string_for_cache="off",
            check_presence_cookie="cookiename",
            cache_reserve_eligibility="bypass_cache_reserve",
            query_string_mode="ignore_all",
            rule="http.host eq \\"video.example.com\\"",
            cache_deception_armor="off",
            site_id=default.sites[0].id,
            bypass_cache="cache_all",
            edge_cache_ttl="300",
            rule_enable="off",
            site_version=0,
            include_header="example",
            serve_stale="off")
        ```

        ## Import

        ESA Cache Rule can be imported using the id, e.g.

        ```sh
        $ pulumi import alicloud:esa/cacheRule:CacheRule example <site_id>:<cache_rule_id>
        ```

        :param str resource_name: The name of the resource.
        :param pulumi.ResourceOptions opts: Options for the resource.
        :param pulumi.Input[builtins.str] additional_cacheable_ports: Enable caching on specified ports. Value range: 8880, 2052, 2082, 2086, 2095, 2053, 2083, 2087, 2096
        :param pulumi.Input[builtins.str] browser_cache_mode: Browser cache mode. Possible values:
        :param pulumi.Input[builtins.str] browser_cache_ttl: Browser cache expiration time in seconds.
        :param pulumi.Input[builtins.str] bypass_cache: Set the bypass cache mode. Possible values:
        :param pulumi.Input[builtins.str] cache_deception_armor: Cache deception protection. Used to defend against web cache deception attacks, only the cache content that passes the validation will be cached. Value range:
        :param pulumi.Input[builtins.str] cache_reserve_eligibility: Cache retention eligibility. Used to control whether user requests bypass the cache retention node when returning to the origin. Possible values:
        :param pulumi.Input[builtins.str] check_presence_cookie: When generating the cache key, check if the cookie exists. If it does, add the cookie name (case-insensitive) to the cache key. Multiple cookie names are supported, separated by spaces.
        :param pulumi.Input[builtins.str] check_presence_header: When generating the cache key, check if the header exists. If it does, add the header name (case-insensitive) to the cache key. Multiple header names are supported, separated by spaces.
        :param pulumi.Input[builtins.str] edge_cache_mode: Edge cache mode. Possible values:
        :param pulumi.Input[builtins.str] edge_cache_ttl: Edge cache expiration time in seconds.
        :param pulumi.Input[builtins.str] edge_status_code_cache_ttl: Status code cache expiration time in seconds.
        :param pulumi.Input[builtins.str] include_cookie: When generating the cache key, add the specified cookie names and their values. Multiple values are supported, separated by spaces.
        :param pulumi.Input[builtins.str] include_header: When generating the cache key, add the specified header names and their values. Multiple values are supported, separated by spaces.
        :param pulumi.Input[builtins.str] query_string: Query strings to be reserved or excluded. Multiple values are supported, separated by spaces.
        :param pulumi.Input[builtins.str] query_string_mode: The processing mode for query strings when generating the cache key. Possible values:
        :param pulumi.Input[builtins.str] rule: Rule content, using conditional expressions to match user requests. When adding global configuration, this parameter does not need to be set. There are two usage scenarios:
               - Match all incoming requests: value set to true.
               - Match specified request: Set the value to a custom expression, for example: (http.host eq \\"video.example.com\\").
        :param pulumi.Input[builtins.str] rule_enable: Rule switch. When adding global configuration, this parameter does not need to be set. Value range:
        :param pulumi.Input[builtins.str] rule_name: Rule name. When adding global configuration, this parameter does not need to be set.
        :param pulumi.Input[builtins.str] serve_stale: Serve stale cache. When enabled, the node can still respond to user requests with expired cached files when the origin server is unavailable. Value range:
        :param pulumi.Input[builtins.int] site_id: The site ID, which can be obtained by calling the [ListSites] API.
        :param pulumi.Input[builtins.int] site_version: The version number of the site configuration. For sites that have enabled configuration version management, this parameter can be used to specify the effective version of the configuration site, which defaults to version 0.
        :param pulumi.Input[builtins.str] sort_query_string_for_cache: Query string sorting, disabled by default. Possible values:
        :param pulumi.Input[builtins.str] user_device_type: When generating the cache key, add the client device type. Possible values:
        :param pulumi.Input[builtins.str] user_geo: When generating the cache key, add the client's geographic location. Possible values:
        :param pulumi.Input[builtins.str] user_language: When generating cache keys, include the client's language type. Possible values:
        """
        ...
    @overload
    def __init__(__self__,
                 resource_name: str,
                 args: CacheRuleArgs,
                 opts: Optional[pulumi.ResourceOptions] = None):
        """
        Provides a ESA Cache Rule resource.

        For information about ESA Cache Rule and how to use it, see [What is Cache Rule](https://next.api.alibabacloud.com/document/ESA/2024-09-10/CreateCacheRule).

        > **NOTE:** Available since v1.244.0.

        ## Example Usage

        Basic Usage

        ```python
        import pulumi
        import pulumi_alicloud as alicloud

        default = alicloud.esa.get_sites(plan_subscribe_type="enterpriseplan")
        default_cache_rule = alicloud.esa.CacheRule("default",
            user_device_type="off",
            browser_cache_mode="no_cache",
            user_language="off",
            check_presence_header="headername",
            include_cookie="cookie_exapmle",
            edge_cache_mode="follow_origin",
            additional_cacheable_ports="2053",
            rule_name="rule_example",
            edge_status_code_cache_ttl="300",
            browser_cache_ttl="300",
            query_string="example",
            user_geo="off",
            sort_query_string_for_cache="off",
            check_presence_cookie="cookiename",
            cache_reserve_eligibility="bypass_cache_reserve",
            query_string_mode="ignore_all",
            rule="http.host eq \\"video.example.com\\"",
            cache_deception_armor="off",
            site_id=default.sites[0].id,
            bypass_cache="cache_all",
            edge_cache_ttl="300",
            rule_enable="off",
            site_version=0,
            include_header="example",
            serve_stale="off")
        ```

        ## Import

        ESA Cache Rule can be imported using the id, e.g.

        ```sh
        $ pulumi import alicloud:esa/cacheRule:CacheRule example <site_id>:<cache_rule_id>
        ```

        :param str resource_name: The name of the resource.
        :param CacheRuleArgs args: The arguments to use to populate this resource's properties.
        :param pulumi.ResourceOptions opts: Options for the resource.
        """
        ...
    def __init__(__self__, resource_name: str, *args, **kwargs):
        resource_args, opts = _utilities.get_resource_args_opts(CacheRuleArgs, pulumi.ResourceOptions, *args, **kwargs)
        if resource_args is not None:
            __self__._internal_init(resource_name, opts, **resource_args.__dict__)
        else:
            __self__._internal_init(resource_name, *args, **kwargs)

    def _internal_init(__self__,
                 resource_name: str,
                 opts: Optional[pulumi.ResourceOptions] = None,
                 additional_cacheable_ports: Optional[pulumi.Input[builtins.str]] = None,
                 browser_cache_mode: Optional[pulumi.Input[builtins.str]] = None,
                 browser_cache_ttl: Optional[pulumi.Input[builtins.str]] = None,
                 bypass_cache: Optional[pulumi.Input[builtins.str]] = None,
                 cache_deception_armor: Optional[pulumi.Input[builtins.str]] = None,
                 cache_reserve_eligibility: Optional[pulumi.Input[builtins.str]] = None,
                 check_presence_cookie: Optional[pulumi.Input[builtins.str]] = None,
                 check_presence_header: Optional[pulumi.Input[builtins.str]] = None,
                 edge_cache_mode: Optional[pulumi.Input[builtins.str]] = None,
                 edge_cache_ttl: Optional[pulumi.Input[builtins.str]] = None,
                 edge_status_code_cache_ttl: Optional[pulumi.Input[builtins.str]] = None,
                 include_cookie: Optional[pulumi.Input[builtins.str]] = None,
                 include_header: Optional[pulumi.Input[builtins.str]] = None,
                 query_string: Optional[pulumi.Input[builtins.str]] = None,
                 query_string_mode: Optional[pulumi.Input[builtins.str]] = None,
                 rule: Optional[pulumi.Input[builtins.str]] = None,
                 rule_enable: Optional[pulumi.Input[builtins.str]] = None,
                 rule_name: Optional[pulumi.Input[builtins.str]] = None,
                 serve_stale: Optional[pulumi.Input[builtins.str]] = None,
                 site_id: Optional[pulumi.Input[builtins.int]] = None,
                 site_version: Optional[pulumi.Input[builtins.int]] = None,
                 sort_query_string_for_cache: Optional[pulumi.Input[builtins.str]] = None,
                 user_device_type: Optional[pulumi.Input[builtins.str]] = None,
                 user_geo: Optional[pulumi.Input[builtins.str]] = None,
                 user_language: Optional[pulumi.Input[builtins.str]] = None,
                 __props__=None):
        opts = pulumi.ResourceOptions.merge(_utilities.get_resource_opts_defaults(), opts)
        if not isinstance(opts, pulumi.ResourceOptions):
            raise TypeError('Expected resource options to be a ResourceOptions instance')
        if opts.id is None:
            if __props__ is not None:
                raise TypeError('__props__ is only valid when passed in combination with a valid opts.id to get an existing resource')
            __props__ = CacheRuleArgs.__new__(CacheRuleArgs)

            __props__.__dict__["additional_cacheable_ports"] = additional_cacheable_ports
            __props__.__dict__["browser_cache_mode"] = browser_cache_mode
            __props__.__dict__["browser_cache_ttl"] = browser_cache_ttl
            __props__.__dict__["bypass_cache"] = bypass_cache
            __props__.__dict__["cache_deception_armor"] = cache_deception_armor
            __props__.__dict__["cache_reserve_eligibility"] = cache_reserve_eligibility
            __props__.__dict__["check_presence_cookie"] = check_presence_cookie
            __props__.__dict__["check_presence_header"] = check_presence_header
            __props__.__dict__["edge_cache_mode"] = edge_cache_mode
            __props__.__dict__["edge_cache_ttl"] = edge_cache_ttl
            __props__.__dict__["edge_status_code_cache_ttl"] = edge_status_code_cache_ttl
            __props__.__dict__["include_cookie"] = include_cookie
            __props__.__dict__["include_header"] = include_header
            __props__.__dict__["query_string"] = query_string
            __props__.__dict__["query_string_mode"] = query_string_mode
            __props__.__dict__["rule"] = rule
            __props__.__dict__["rule_enable"] = rule_enable
            __props__.__dict__["rule_name"] = rule_name
            __props__.__dict__["serve_stale"] = serve_stale
            if site_id is None and not opts.urn:
                raise TypeError("Missing required property 'site_id'")
            __props__.__dict__["site_id"] = site_id
            __props__.__dict__["site_version"] = site_version
            __props__.__dict__["sort_query_string_for_cache"] = sort_query_string_for_cache
            __props__.__dict__["user_device_type"] = user_device_type
            __props__.__dict__["user_geo"] = user_geo
            __props__.__dict__["user_language"] = user_language
            __props__.__dict__["cache_rule_id"] = None
        super(CacheRule, __self__).__init__(
            'alicloud:esa/cacheRule:CacheRule',
            resource_name,
            __props__,
            opts)

    @staticmethod
    def get(resource_name: str,
            id: pulumi.Input[str],
            opts: Optional[pulumi.ResourceOptions] = None,
            additional_cacheable_ports: Optional[pulumi.Input[builtins.str]] = None,
            browser_cache_mode: Optional[pulumi.Input[builtins.str]] = None,
            browser_cache_ttl: Optional[pulumi.Input[builtins.str]] = None,
            bypass_cache: Optional[pulumi.Input[builtins.str]] = None,
            cache_deception_armor: Optional[pulumi.Input[builtins.str]] = None,
            cache_reserve_eligibility: Optional[pulumi.Input[builtins.str]] = None,
            cache_rule_id: Optional[pulumi.Input[builtins.int]] = None,
            check_presence_cookie: Optional[pulumi.Input[builtins.str]] = None,
            check_presence_header: Optional[pulumi.Input[builtins.str]] = None,
            edge_cache_mode: Optional[pulumi.Input[builtins.str]] = None,
            edge_cache_ttl: Optional[pulumi.Input[builtins.str]] = None,
            edge_status_code_cache_ttl: Optional[pulumi.Input[builtins.str]] = None,
            include_cookie: Optional[pulumi.Input[builtins.str]] = None,
            include_header: Optional[pulumi.Input[builtins.str]] = None,
            query_string: Optional[pulumi.Input[builtins.str]] = None,
            query_string_mode: Optional[pulumi.Input[builtins.str]] = None,
            rule: Optional[pulumi.Input[builtins.str]] = None,
            rule_enable: Optional[pulumi.Input[builtins.str]] = None,
            rule_name: Optional[pulumi.Input[builtins.str]] = None,
            serve_stale: Optional[pulumi.Input[builtins.str]] = None,
            site_id: Optional[pulumi.Input[builtins.int]] = None,
            site_version: Optional[pulumi.Input[builtins.int]] = None,
            sort_query_string_for_cache: Optional[pulumi.Input[builtins.str]] = None,
            user_device_type: Optional[pulumi.Input[builtins.str]] = None,
            user_geo: Optional[pulumi.Input[builtins.str]] = None,
            user_language: Optional[pulumi.Input[builtins.str]] = None) -> 'CacheRule':
        """
        Get an existing CacheRule resource's state with the given name, id, and optional extra
        properties used to qualify the lookup.

        :param str resource_name: The unique name of the resulting resource.
        :param pulumi.Input[str] id: The unique provider ID of the resource to lookup.
        :param pulumi.ResourceOptions opts: Options for the resource.
        :param pulumi.Input[builtins.str] additional_cacheable_ports: Enable caching on specified ports. Value range: 8880, 2052, 2082, 2086, 2095, 2053, 2083, 2087, 2096
        :param pulumi.Input[builtins.str] browser_cache_mode: Browser cache mode. Possible values:
        :param pulumi.Input[builtins.str] browser_cache_ttl: Browser cache expiration time in seconds.
        :param pulumi.Input[builtins.str] bypass_cache: Set the bypass cache mode. Possible values:
        :param pulumi.Input[builtins.str] cache_deception_armor: Cache deception protection. Used to defend against web cache deception attacks, only the cache content that passes the validation will be cached. Value range:
        :param pulumi.Input[builtins.str] cache_reserve_eligibility: Cache retention eligibility. Used to control whether user requests bypass the cache retention node when returning to the origin. Possible values:
        :param pulumi.Input[builtins.int] cache_rule_id: Cache Rule Id.
        :param pulumi.Input[builtins.str] check_presence_cookie: When generating the cache key, check if the cookie exists. If it does, add the cookie name (case-insensitive) to the cache key. Multiple cookie names are supported, separated by spaces.
        :param pulumi.Input[builtins.str] check_presence_header: When generating the cache key, check if the header exists. If it does, add the header name (case-insensitive) to the cache key. Multiple header names are supported, separated by spaces.
        :param pulumi.Input[builtins.str] edge_cache_mode: Edge cache mode. Possible values:
        :param pulumi.Input[builtins.str] edge_cache_ttl: Edge cache expiration time in seconds.
        :param pulumi.Input[builtins.str] edge_status_code_cache_ttl: Status code cache expiration time in seconds.
        :param pulumi.Input[builtins.str] include_cookie: When generating the cache key, add the specified cookie names and their values. Multiple values are supported, separated by spaces.
        :param pulumi.Input[builtins.str] include_header: When generating the cache key, add the specified header names and their values. Multiple values are supported, separated by spaces.
        :param pulumi.Input[builtins.str] query_string: Query strings to be reserved or excluded. Multiple values are supported, separated by spaces.
        :param pulumi.Input[builtins.str] query_string_mode: The processing mode for query strings when generating the cache key. Possible values:
        :param pulumi.Input[builtins.str] rule: Rule content, using conditional expressions to match user requests. When adding global configuration, this parameter does not need to be set. There are two usage scenarios:
               - Match all incoming requests: value set to true.
               - Match specified request: Set the value to a custom expression, for example: (http.host eq \\"video.example.com\\").
        :param pulumi.Input[builtins.str] rule_enable: Rule switch. When adding global configuration, this parameter does not need to be set. Value range:
        :param pulumi.Input[builtins.str] rule_name: Rule name. When adding global configuration, this parameter does not need to be set.
        :param pulumi.Input[builtins.str] serve_stale: Serve stale cache. When enabled, the node can still respond to user requests with expired cached files when the origin server is unavailable. Value range:
        :param pulumi.Input[builtins.int] site_id: The site ID, which can be obtained by calling the [ListSites] API.
        :param pulumi.Input[builtins.int] site_version: The version number of the site configuration. For sites that have enabled configuration version management, this parameter can be used to specify the effective version of the configuration site, which defaults to version 0.
        :param pulumi.Input[builtins.str] sort_query_string_for_cache: Query string sorting, disabled by default. Possible values:
        :param pulumi.Input[builtins.str] user_device_type: When generating the cache key, add the client device type. Possible values:
        :param pulumi.Input[builtins.str] user_geo: When generating the cache key, add the client's geographic location. Possible values:
        :param pulumi.Input[builtins.str] user_language: When generating cache keys, include the client's language type. Possible values:
        """
        opts = pulumi.ResourceOptions.merge(opts, pulumi.ResourceOptions(id=id))

        __props__ = _CacheRuleState.__new__(_CacheRuleState)

        __props__.__dict__["additional_cacheable_ports"] = additional_cacheable_ports
        __props__.__dict__["browser_cache_mode"] = browser_cache_mode
        __props__.__dict__["browser_cache_ttl"] = browser_cache_ttl
        __props__.__dict__["bypass_cache"] = bypass_cache
        __props__.__dict__["cache_deception_armor"] = cache_deception_armor
        __props__.__dict__["cache_reserve_eligibility"] = cache_reserve_eligibility
        __props__.__dict__["cache_rule_id"] = cache_rule_id
        __props__.__dict__["check_presence_cookie"] = check_presence_cookie
        __props__.__dict__["check_presence_header"] = check_presence_header
        __props__.__dict__["edge_cache_mode"] = edge_cache_mode
        __props__.__dict__["edge_cache_ttl"] = edge_cache_ttl
        __props__.__dict__["edge_status_code_cache_ttl"] = edge_status_code_cache_ttl
        __props__.__dict__["include_cookie"] = include_cookie
        __props__.__dict__["include_header"] = include_header
        __props__.__dict__["query_string"] = query_string
        __props__.__dict__["query_string_mode"] = query_string_mode
        __props__.__dict__["rule"] = rule
        __props__.__dict__["rule_enable"] = rule_enable
        __props__.__dict__["rule_name"] = rule_name
        __props__.__dict__["serve_stale"] = serve_stale
        __props__.__dict__["site_id"] = site_id
        __props__.__dict__["site_version"] = site_version
        __props__.__dict__["sort_query_string_for_cache"] = sort_query_string_for_cache
        __props__.__dict__["user_device_type"] = user_device_type
        __props__.__dict__["user_geo"] = user_geo
        __props__.__dict__["user_language"] = user_language
        return CacheRule(resource_name, opts=opts, __props__=__props__)

    @property
    @pulumi.getter(name="additionalCacheablePorts")
    def additional_cacheable_ports(self) -> pulumi.Output[Optional[builtins.str]]:
        """
        Enable caching on specified ports. Value range: 8880, 2052, 2082, 2086, 2095, 2053, 2083, 2087, 2096
        """
        return pulumi.get(self, "additional_cacheable_ports")

    @property
    @pulumi.getter(name="browserCacheMode")
    def browser_cache_mode(self) -> pulumi.Output[Optional[builtins.str]]:
        """
        Browser cache mode. Possible values:
        """
        return pulumi.get(self, "browser_cache_mode")

    @property
    @pulumi.getter(name="browserCacheTtl")
    def browser_cache_ttl(self) -> pulumi.Output[Optional[builtins.str]]:
        """
        Browser cache expiration time in seconds.
        """
        return pulumi.get(self, "browser_cache_ttl")

    @property
    @pulumi.getter(name="bypassCache")
    def bypass_cache(self) -> pulumi.Output[Optional[builtins.str]]:
        """
        Set the bypass cache mode. Possible values:
        """
        return pulumi.get(self, "bypass_cache")

    @property
    @pulumi.getter(name="cacheDeceptionArmor")
    def cache_deception_armor(self) -> pulumi.Output[Optional[builtins.str]]:
        """
        Cache deception protection. Used to defend against web cache deception attacks, only the cache content that passes the validation will be cached. Value range:
        """
        return pulumi.get(self, "cache_deception_armor")

    @property
    @pulumi.getter(name="cacheReserveEligibility")
    def cache_reserve_eligibility(self) -> pulumi.Output[Optional[builtins.str]]:
        """
        Cache retention eligibility. Used to control whether user requests bypass the cache retention node when returning to the origin. Possible values:
        """
        return pulumi.get(self, "cache_reserve_eligibility")

    @property
    @pulumi.getter(name="cacheRuleId")
    def cache_rule_id(self) -> pulumi.Output[builtins.int]:
        """
        Cache Rule Id.
        """
        return pulumi.get(self, "cache_rule_id")

    @property
    @pulumi.getter(name="checkPresenceCookie")
    def check_presence_cookie(self) -> pulumi.Output[Optional[builtins.str]]:
        """
        When generating the cache key, check if the cookie exists. If it does, add the cookie name (case-insensitive) to the cache key. Multiple cookie names are supported, separated by spaces.
        """
        return pulumi.get(self, "check_presence_cookie")

    @property
    @pulumi.getter(name="checkPresenceHeader")
    def check_presence_header(self) -> pulumi.Output[Optional[builtins.str]]:
        """
        When generating the cache key, check if the header exists. If it does, add the header name (case-insensitive) to the cache key. Multiple header names are supported, separated by spaces.
        """
        return pulumi.get(self, "check_presence_header")

    @property
    @pulumi.getter(name="edgeCacheMode")
    def edge_cache_mode(self) -> pulumi.Output[Optional[builtins.str]]:
        """
        Edge cache mode. Possible values:
        """
        return pulumi.get(self, "edge_cache_mode")

    @property
    @pulumi.getter(name="edgeCacheTtl")
    def edge_cache_ttl(self) -> pulumi.Output[Optional[builtins.str]]:
        """
        Edge cache expiration time in seconds.
        """
        return pulumi.get(self, "edge_cache_ttl")

    @property
    @pulumi.getter(name="edgeStatusCodeCacheTtl")
    def edge_status_code_cache_ttl(self) -> pulumi.Output[Optional[builtins.str]]:
        """
        Status code cache expiration time in seconds.
        """
        return pulumi.get(self, "edge_status_code_cache_ttl")

    @property
    @pulumi.getter(name="includeCookie")
    def include_cookie(self) -> pulumi.Output[Optional[builtins.str]]:
        """
        When generating the cache key, add the specified cookie names and their values. Multiple values are supported, separated by spaces.
        """
        return pulumi.get(self, "include_cookie")

    @property
    @pulumi.getter(name="includeHeader")
    def include_header(self) -> pulumi.Output[Optional[builtins.str]]:
        """
        When generating the cache key, add the specified header names and their values. Multiple values are supported, separated by spaces.
        """
        return pulumi.get(self, "include_header")

    @property
    @pulumi.getter(name="queryString")
    def query_string(self) -> pulumi.Output[Optional[builtins.str]]:
        """
        Query strings to be reserved or excluded. Multiple values are supported, separated by spaces.
        """
        return pulumi.get(self, "query_string")

    @property
    @pulumi.getter(name="queryStringMode")
    def query_string_mode(self) -> pulumi.Output[Optional[builtins.str]]:
        """
        The processing mode for query strings when generating the cache key. Possible values:
        """
        return pulumi.get(self, "query_string_mode")

    @property
    @pulumi.getter
    def rule(self) -> pulumi.Output[Optional[builtins.str]]:
        """
        Rule content, using conditional expressions to match user requests. When adding global configuration, this parameter does not need to be set. There are two usage scenarios:
        - Match all incoming requests: value set to true.
        - Match specified request: Set the value to a custom expression, for example: (http.host eq \\"video.example.com\\").
        """
        return pulumi.get(self, "rule")

    @property
    @pulumi.getter(name="ruleEnable")
    def rule_enable(self) -> pulumi.Output[Optional[builtins.str]]:
        """
        Rule switch. When adding global configuration, this parameter does not need to be set. Value range:
        """
        return pulumi.get(self, "rule_enable")

    @property
    @pulumi.getter(name="ruleName")
    def rule_name(self) -> pulumi.Output[Optional[builtins.str]]:
        """
        Rule name. When adding global configuration, this parameter does not need to be set.
        """
        return pulumi.get(self, "rule_name")

    @property
    @pulumi.getter(name="serveStale")
    def serve_stale(self) -> pulumi.Output[Optional[builtins.str]]:
        """
        Serve stale cache. When enabled, the node can still respond to user requests with expired cached files when the origin server is unavailable. Value range:
        """
        return pulumi.get(self, "serve_stale")

    @property
    @pulumi.getter(name="siteId")
    def site_id(self) -> pulumi.Output[builtins.int]:
        """
        The site ID, which can be obtained by calling the [ListSites] API.
        """
        return pulumi.get(self, "site_id")

    @property
    @pulumi.getter(name="siteVersion")
    def site_version(self) -> pulumi.Output[Optional[builtins.int]]:
        """
        The version number of the site configuration. For sites that have enabled configuration version management, this parameter can be used to specify the effective version of the configuration site, which defaults to version 0.
        """
        return pulumi.get(self, "site_version")

    @property
    @pulumi.getter(name="sortQueryStringForCache")
    def sort_query_string_for_cache(self) -> pulumi.Output[Optional[builtins.str]]:
        """
        Query string sorting, disabled by default. Possible values:
        """
        return pulumi.get(self, "sort_query_string_for_cache")

    @property
    @pulumi.getter(name="userDeviceType")
    def user_device_type(self) -> pulumi.Output[Optional[builtins.str]]:
        """
        When generating the cache key, add the client device type. Possible values:
        """
        return pulumi.get(self, "user_device_type")

    @property
    @pulumi.getter(name="userGeo")
    def user_geo(self) -> pulumi.Output[Optional[builtins.str]]:
        """
        When generating the cache key, add the client's geographic location. Possible values:
        """
        return pulumi.get(self, "user_geo")

    @property
    @pulumi.getter(name="userLanguage")
    def user_language(self) -> pulumi.Output[Optional[builtins.str]]:
        """
        When generating cache keys, include the client's language type. Possible values:
        """
        return pulumi.get(self, "user_language")




# coding=utf-8
# *** WARNING: this file was generated by the Pulumi Terraform Bridge (tfgen) Tool. ***
# *** Do not edit by hand unless you're certain you know what you are doing! ***

import builtins
import copy
import warnings
import sys
import pulumi
import pulumi.runtime
from typing import Any, Mapping, Optional, Sequence, Union, overload
if sys.version_info >= (3, 11):
    from typing import NotRequired, TypedDict, TypeAlias
else:
    from typing_extensions import NotRequired, TypedDict, TypeAlias
from .. import _utilities
from . import outputs

__all__ = [
    'GetSnapshotsResult',
    'AwaitableGetSnapshotsResult',
    'get_snapshots',
    'get_snapshots_output',
]

@pulumi.output_type
class GetSnapshotsResult:
    """
    A collection of values returned by getSnapshots.
    """
    def __init__(__self__, desktop_id=None, id=None, ids=None, name_regex=None, names=None, output_file=None, snapshot_id=None, snapshots=None):
        if desktop_id and not isinstance(desktop_id, str):
            raise TypeError("Expected argument 'desktop_id' to be a str")
        pulumi.set(__self__, "desktop_id", desktop_id)
        if id and not isinstance(id, str):
            raise TypeError("Expected argument 'id' to be a str")
        pulumi.set(__self__, "id", id)
        if ids and not isinstance(ids, list):
            raise TypeError("Expected argument 'ids' to be a list")
        pulumi.set(__self__, "ids", ids)
        if name_regex and not isinstance(name_regex, str):
            raise TypeError("Expected argument 'name_regex' to be a str")
        pulumi.set(__self__, "name_regex", name_regex)
        if names and not isinstance(names, list):
            raise TypeError("Expected argument 'names' to be a list")
        pulumi.set(__self__, "names", names)
        if output_file and not isinstance(output_file, str):
            raise TypeError("Expected argument 'output_file' to be a str")
        pulumi.set(__self__, "output_file", output_file)
        if snapshot_id and not isinstance(snapshot_id, str):
            raise TypeError("Expected argument 'snapshot_id' to be a str")
        pulumi.set(__self__, "snapshot_id", snapshot_id)
        if snapshots and not isinstance(snapshots, list):
            raise TypeError("Expected argument 'snapshots' to be a list")
        pulumi.set(__self__, "snapshots", snapshots)

    @property
    @pulumi.getter(name="desktopId")
    def desktop_id(self) -> Optional[builtins.str]:
        return pulumi.get(self, "desktop_id")

    @property
    @pulumi.getter
    def id(self) -> builtins.str:
        """
        The provider-assigned unique ID for this managed resource.
        """
        return pulumi.get(self, "id")

    @property
    @pulumi.getter
    def ids(self) -> Sequence[builtins.str]:
        return pulumi.get(self, "ids")

    @property
    @pulumi.getter(name="nameRegex")
    def name_regex(self) -> Optional[builtins.str]:
        return pulumi.get(self, "name_regex")

    @property
    @pulumi.getter
    def names(self) -> Sequence[builtins.str]:
        return pulumi.get(self, "names")

    @property
    @pulumi.getter(name="outputFile")
    def output_file(self) -> Optional[builtins.str]:
        return pulumi.get(self, "output_file")

    @property
    @pulumi.getter(name="snapshotId")
    def snapshot_id(self) -> Optional[builtins.str]:
        return pulumi.get(self, "snapshot_id")

    @property
    @pulumi.getter
    def snapshots(self) -> Sequence['outputs.GetSnapshotsSnapshotResult']:
        return pulumi.get(self, "snapshots")


class AwaitableGetSnapshotsResult(GetSnapshotsResult):
    # pylint: disable=using-constant-test
    def __await__(self):
        if False:
            yield self
        return GetSnapshotsResult(
            desktop_id=self.desktop_id,
            id=self.id,
            ids=self.ids,
            name_regex=self.name_regex,
            names=self.names,
            output_file=self.output_file,
            snapshot_id=self.snapshot_id,
            snapshots=self.snapshots)


def get_snapshots(desktop_id: Optional[builtins.str] = None,
                  ids: Optional[Sequence[builtins.str]] = None,
                  name_regex: Optional[builtins.str] = None,
                  output_file: Optional[builtins.str] = None,
                  snapshot_id: Optional[builtins.str] = None,
                  opts: Optional[pulumi.InvokeOptions] = None) -> AwaitableGetSnapshotsResult:
    """
    This data source provides the Ecd Snapshots of the current Alibaba Cloud user.

    > **NOTE:** Available in v1.169.0+.

    ## Example Usage

    Basic Usage

    ```python
    import pulumi
    import pulumi_alicloud as alicloud

    ids = alicloud.eds.get_snapshots()
    pulumi.export("ecdSnapshotId1", ids.snapshots[0].id)
    ```


    :param builtins.str desktop_id: The ID of the Desktop.
    :param Sequence[builtins.str] ids: A list of Snapshot IDs.
    :param builtins.str name_regex: A regex string to filter results by Snapshot name.
    :param builtins.str output_file: File name where to save data source results (after running `pulumi preview`).
    :param builtins.str snapshot_id: The ID of the Snapshot.
    """
    __args__ = dict()
    __args__['desktopId'] = desktop_id
    __args__['ids'] = ids
    __args__['nameRegex'] = name_regex
    __args__['outputFile'] = output_file
    __args__['snapshotId'] = snapshot_id
    opts = pulumi.InvokeOptions.merge(_utilities.get_invoke_opts_defaults(), opts)
    __ret__ = pulumi.runtime.invoke('alicloud:eds/getSnapshots:getSnapshots', __args__, opts=opts, typ=GetSnapshotsResult).value

    return AwaitableGetSnapshotsResult(
        desktop_id=pulumi.get(__ret__, 'desktop_id'),
        id=pulumi.get(__ret__, 'id'),
        ids=pulumi.get(__ret__, 'ids'),
        name_regex=pulumi.get(__ret__, 'name_regex'),
        names=pulumi.get(__ret__, 'names'),
        output_file=pulumi.get(__ret__, 'output_file'),
        snapshot_id=pulumi.get(__ret__, 'snapshot_id'),
        snapshots=pulumi.get(__ret__, 'snapshots'))
def get_snapshots_output(desktop_id: Optional[pulumi.Input[Optional[builtins.str]]] = None,
                         ids: Optional[pulumi.Input[Optional[Sequence[builtins.str]]]] = None,
                         name_regex: Optional[pulumi.Input[Optional[builtins.str]]] = None,
                         output_file: Optional[pulumi.Input[Optional[builtins.str]]] = None,
                         snapshot_id: Optional[pulumi.Input[Optional[builtins.str]]] = None,
                         opts: Optional[Union[pulumi.InvokeOptions, pulumi.InvokeOutputOptions]] = None) -> pulumi.Output[GetSnapshotsResult]:
    """
    This data source provides the Ecd Snapshots of the current Alibaba Cloud user.

    > **NOTE:** Available in v1.169.0+.

    ## Example Usage

    Basic Usage

    ```python
    import pulumi
    import pulumi_alicloud as alicloud

    ids = alicloud.eds.get_snapshots()
    pulumi.export("ecdSnapshotId1", ids.snapshots[0].id)
    ```


    :param builtins.str desktop_id: The ID of the Desktop.
    :param Sequence[builtins.str] ids: A list of Snapshot IDs.
    :param builtins.str name_regex: A regex string to filter results by Snapshot name.
    :param builtins.str output_file: File name where to save data source results (after running `pulumi preview`).
    :param builtins.str snapshot_id: The ID of the Snapshot.
    """
    __args__ = dict()
    __args__['desktopId'] = desktop_id
    __args__['ids'] = ids
    __args__['nameRegex'] = name_regex
    __args__['outputFile'] = output_file
    __args__['snapshotId'] = snapshot_id
    opts = pulumi.InvokeOutputOptions.merge(_utilities.get_invoke_opts_defaults(), opts)
    __ret__ = pulumi.runtime.invoke_output('alicloud:eds/getSnapshots:getSnapshots', __args__, opts=opts, typ=GetSnapshotsResult)
    return __ret__.apply(lambda __response__: GetSnapshotsResult(
        desktop_id=pulumi.get(__response__, 'desktop_id'),
        id=pulumi.get(__response__, 'id'),
        ids=pulumi.get(__response__, 'ids'),
        name_regex=pulumi.get(__response__, 'name_regex'),
        names=pulumi.get(__response__, 'names'),
        output_file=pulumi.get(__response__, 'output_file'),
        snapshot_id=pulumi.get(__response__, 'snapshot_id'),
        snapshots=pulumi.get(__response__, 'snapshots')))



# coding=utf-8
# *** WARNING: this file was generated by the Pulumi Terraform Bridge (tfgen) Tool. ***
# *** Do not edit by hand unless you're certain you know what you are doing! ***

import builtins
from .. import _utilities
import typing
# Export this package's modules as members:
from .flow_pipeline import *
from .service import *
from .workspace_code_source import *
from .workspace_dataset import *
from .workspace_datasetversion import *
from .workspace_experiment import *
from .workspace_member import *
from .workspace_model import *
from .workspace_model_version import *
from .workspace_run import *
from .workspace_user_config import *
from .workspace_workspace import *
from ._inputs import *
from . import outputs



# coding=utf-8
# *** WARNING: this file was generated by the Pulumi Terraform Bridge (tfgen) Tool. ***
# *** Do not edit by hand unless you're certain you know what you are doing! ***

import builtins
import copy
import warnings
import sys
import pulumi
import pulumi.runtime
from typing import Any, Mapping, Optional, Sequence, Union, overload
if sys.version_info >= (3, 11):
    from typing import NotRequired, TypedDict, TypeAlias
else:
    from typing_extensions import NotRequired, TypedDict, TypeAlias
from .. import _utilities

__all__ = ['FileSystemArgs', 'FileSystem']

@pulumi.input_type
class FileSystemArgs:
    def __init__(__self__, *,
                 file_system_name: pulumi.Input[builtins.str],
                 protocol_type: pulumi.Input[builtins.str],
                 space_capacity: pulumi.Input[builtins.int],
                 storage_type: pulumi.Input[builtins.str],
                 data_redundancy_type: Optional[pulumi.Input[builtins.str]] = None,
                 dedicated_cluster_id: Optional[pulumi.Input[builtins.str]] = None,
                 description: Optional[pulumi.Input[builtins.str]] = None,
                 partition_number: Optional[pulumi.Input[builtins.int]] = None,
                 provisioned_throughput_in_mi_bps: Optional[pulumi.Input[builtins.int]] = None,
                 storage_set_name: Optional[pulumi.Input[builtins.str]] = None,
                 throughput_mode: Optional[pulumi.Input[builtins.str]] = None,
                 zone_id: Optional[pulumi.Input[builtins.str]] = None):
        """
        The set of arguments for constructing a FileSystem resource.
        :param pulumi.Input[builtins.str] file_system_name: The file system name. The naming rules are as follows: The length is 6~64 characters. Globally unique and cannot be an empty string. English letters are supported and can contain numbers, underscores (_), and dashes (-).
        :param pulumi.Input[builtins.str] protocol_type: The protocol type. Value: `HDFS`, `PANGU`.
        :param pulumi.Input[builtins.int] space_capacity: File system capacity.  When the actual amount of data stored reaches the capacity of the file system, data cannot be written.  Unit: GiB.
        :param pulumi.Input[builtins.str] storage_type: The storage media type. Value: STANDARD (default): STANDARD PERFORMANCE: PERFORMANCE type.
        :param pulumi.Input[builtins.str] data_redundancy_type: Redundancy mode of the file system. Value:
               - LRS (default): Local redundancy.
               - ZRS: Same-City redundancy. When ZRS is selected, zoneId is a string consisting of multiple zones that are expected to be redundant in the same city, for example,  'zoneId1,zoneId2 '.
        :param pulumi.Input[builtins.str] dedicated_cluster_id: Dedicated cluster id, which is used to support scenarios such as group cloud migration.
        :param pulumi.Input[builtins.str] description: The description of the file system resource. No more than 32 characters in length.
        :param pulumi.Input[builtins.int] partition_number: Save set sequence number, the user selects the content of the specified sequence number in the Save set.
        :param pulumi.Input[builtins.int] provisioned_throughput_in_mi_bps: Provisioned throughput. This parameter is required when ThroughputMode is set to Provisioned. Unit: MB/s Value range: 1~5120.
        :param pulumi.Input[builtins.str] storage_set_name: Save set identity, used to select a user-specified save set.
        :param pulumi.Input[builtins.str] throughput_mode: The throughput mode. Value: Standard (default): Standard throughput Provisioned: preset throughput.
        :param pulumi.Input[builtins.str] zone_id: Zone Id, which is used to create file system resources to the specified zone.
        """
        pulumi.set(__self__, "file_system_name", file_system_name)
        pulumi.set(__self__, "protocol_type", protocol_type)
        pulumi.set(__self__, "space_capacity", space_capacity)
        pulumi.set(__self__, "storage_type", storage_type)
        if data_redundancy_type is not None:
            pulumi.set(__self__, "data_redundancy_type", data_redundancy_type)
        if dedicated_cluster_id is not None:
            pulumi.set(__self__, "dedicated_cluster_id", dedicated_cluster_id)
        if description is not None:
            pulumi.set(__self__, "description", description)
        if partition_number is not None:
            pulumi.set(__self__, "partition_number", partition_number)
        if provisioned_throughput_in_mi_bps is not None:
            pulumi.set(__self__, "provisioned_throughput_in_mi_bps", provisioned_throughput_in_mi_bps)
        if storage_set_name is not None:
            pulumi.set(__self__, "storage_set_name", storage_set_name)
        if throughput_mode is not None:
            pulumi.set(__self__, "throughput_mode", throughput_mode)
        if zone_id is not None:
            pulumi.set(__self__, "zone_id", zone_id)

    @property
    @pulumi.getter(name="fileSystemName")
    def file_system_name(self) -> pulumi.Input[builtins.str]:
        """
        The file system name. The naming rules are as follows: The length is 6~64 characters. Globally unique and cannot be an empty string. English letters are supported and can contain numbers, underscores (_), and dashes (-).
        """
        return pulumi.get(self, "file_system_name")

    @file_system_name.setter
    def file_system_name(self, value: pulumi.Input[builtins.str]):
        pulumi.set(self, "file_system_name", value)

    @property
    @pulumi.getter(name="protocolType")
    def protocol_type(self) -> pulumi.Input[builtins.str]:
        """
        The protocol type. Value: `HDFS`, `PANGU`.
        """
        return pulumi.get(self, "protocol_type")

    @protocol_type.setter
    def protocol_type(self, value: pulumi.Input[builtins.str]):
        pulumi.set(self, "protocol_type", value)

    @property
    @pulumi.getter(name="spaceCapacity")
    def space_capacity(self) -> pulumi.Input[builtins.int]:
        """
        File system capacity.  When the actual amount of data stored reaches the capacity of the file system, data cannot be written.  Unit: GiB.
        """
        return pulumi.get(self, "space_capacity")

    @space_capacity.setter
    def space_capacity(self, value: pulumi.Input[builtins.int]):
        pulumi.set(self, "space_capacity", value)

    @property
    @pulumi.getter(name="storageType")
    def storage_type(self) -> pulumi.Input[builtins.str]:
        """
        The storage media type. Value: STANDARD (default): STANDARD PERFORMANCE: PERFORMANCE type.
        """
        return pulumi.get(self, "storage_type")

    @storage_type.setter
    def storage_type(self, value: pulumi.Input[builtins.str]):
        pulumi.set(self, "storage_type", value)

    @property
    @pulumi.getter(name="dataRedundancyType")
    def data_redundancy_type(self) -> Optional[pulumi.Input[builtins.str]]:
        """
        Redundancy mode of the file system. Value:
        - LRS (default): Local redundancy.
        - ZRS: Same-City redundancy. When ZRS is selected, zoneId is a string consisting of multiple zones that are expected to be redundant in the same city, for example,  'zoneId1,zoneId2 '.
        """
        return pulumi.get(self, "data_redundancy_type")

    @data_redundancy_type.setter
    def data_redundancy_type(self, value: Optional[pulumi.Input[builtins.str]]):
        pulumi.set(self, "data_redundancy_type", value)

    @property
    @pulumi.getter(name="dedicatedClusterId")
    def dedicated_cluster_id(self) -> Optional[pulumi.Input[builtins.str]]:
        """
        Dedicated cluster id, which is used to support scenarios such as group cloud migration.
        """
        return pulumi.get(self, "dedicated_cluster_id")

    @dedicated_cluster_id.setter
    def dedicated_cluster_id(self, value: Optional[pulumi.Input[builtins.str]]):
        pulumi.set(self, "dedicated_cluster_id", value)

    @property
    @pulumi.getter
    def description(self) -> Optional[pulumi.Input[builtins.str]]:
        """
        The description of the file system resource. No more than 32 characters in length.
        """
        return pulumi.get(self, "description")

    @description.setter
    def description(self, value: Optional[pulumi.Input[builtins.str]]):
        pulumi.set(self, "description", value)

    @property
    @pulumi.getter(name="partitionNumber")
    def partition_number(self) -> Optional[pulumi.Input[builtins.int]]:
        """
        Save set sequence number, the user selects the content of the specified sequence number in the Save set.
        """
        return pulumi.get(self, "partition_number")

    @partition_number.setter
    def partition_number(self, value: Optional[pulumi.Input[builtins.int]]):
        pulumi.set(self, "partition_number", value)

    @property
    @pulumi.getter(name="provisionedThroughputInMiBps")
    def provisioned_throughput_in_mi_bps(self) -> Optional[pulumi.Input[builtins.int]]:
        """
        Provisioned throughput. This parameter is required when ThroughputMode is set to Provisioned. Unit: MB/s Value range: 1~5120.
        """
        return pulumi.get(self, "provisioned_throughput_in_mi_bps")

    @provisioned_throughput_in_mi_bps.setter
    def provisioned_throughput_in_mi_bps(self, value: Optional[pulumi.Input[builtins.int]]):
        pulumi.set(self, "provisioned_throughput_in_mi_bps", value)

    @property
    @pulumi.getter(name="storageSetName")
    def storage_set_name(self) -> Optional[pulumi.Input[builtins.str]]:
        """
        Save set identity, used to select a user-specified save set.
        """
        return pulumi.get(self, "storage_set_name")

    @storage_set_name.setter
    def storage_set_name(self, value: Optional[pulumi.Input[builtins.str]]):
        pulumi.set(self, "storage_set_name", value)

    @property
    @pulumi.getter(name="throughputMode")
    def throughput_mode(self) -> Optional[pulumi.Input[builtins.str]]:
        """
        The throughput mode. Value: Standard (default): Standard throughput Provisioned: preset throughput.
        """
        return pulumi.get(self, "throughput_mode")

    @throughput_mode.setter
    def throughput_mode(self, value: Optional[pulumi.Input[builtins.str]]):
        pulumi.set(self, "throughput_mode", value)

    @property
    @pulumi.getter(name="zoneId")
    def zone_id(self) -> Optional[pulumi.Input[builtins.str]]:
        """
        Zone Id, which is used to create file system resources to the specified zone.
        """
        return pulumi.get(self, "zone_id")

    @zone_id.setter
    def zone_id(self, value: Optional[pulumi.Input[builtins.str]]):
        pulumi.set(self, "zone_id", value)


@pulumi.input_type
class _FileSystemState:
    def __init__(__self__, *,
                 create_time: Optional[pulumi.Input[builtins.str]] = None,
                 data_redundancy_type: Optional[pulumi.Input[builtins.str]] = None,
                 dedicated_cluster_id: Optional[pulumi.Input[builtins.str]] = None,
                 description: Optional[pulumi.Input[builtins.str]] = None,
                 file_system_name: Optional[pulumi.Input[builtins.str]] = None,
                 partition_number: Optional[pulumi.Input[builtins.int]] = None,
                 protocol_type: Optional[pulumi.Input[builtins.str]] = None,
                 provisioned_throughput_in_mi_bps: Optional[pulumi.Input[builtins.int]] = None,
                 region_id: Optional[pulumi.Input[builtins.str]] = None,
                 space_capacity: Optional[pulumi.Input[builtins.int]] = None,
                 storage_set_name: Optional[pulumi.Input[builtins.str]] = None,
                 storage_type: Optional[pulumi.Input[builtins.str]] = None,
                 throughput_mode: Optional[pulumi.Input[builtins.str]] = None,
                 zone_id: Optional[pulumi.Input[builtins.str]] = None):
        """
        Input properties used for looking up and filtering FileSystem resources.
        :param pulumi.Input[builtins.str] create_time: The creation time of the file system instance.
        :param pulumi.Input[builtins.str] data_redundancy_type: Redundancy mode of the file system. Value:
               - LRS (default): Local redundancy.
               - ZRS: Same-City redundancy. When ZRS is selected, zoneId is a string consisting of multiple zones that are expected to be redundant in the same city, for example,  'zoneId1,zoneId2 '.
        :param pulumi.Input[builtins.str] dedicated_cluster_id: Dedicated cluster id, which is used to support scenarios such as group cloud migration.
        :param pulumi.Input[builtins.str] description: The description of the file system resource. No more than 32 characters in length.
        :param pulumi.Input[builtins.str] file_system_name: The file system name. The naming rules are as follows: The length is 6~64 characters. Globally unique and cannot be an empty string. English letters are supported and can contain numbers, underscores (_), and dashes (-).
        :param pulumi.Input[builtins.int] partition_number: Save set sequence number, the user selects the content of the specified sequence number in the Save set.
        :param pulumi.Input[builtins.str] protocol_type: The protocol type. Value: `HDFS`, `PANGU`.
        :param pulumi.Input[builtins.int] provisioned_throughput_in_mi_bps: Provisioned throughput. This parameter is required when ThroughputMode is set to Provisioned. Unit: MB/s Value range: 1~5120.
        :param pulumi.Input[builtins.str] region_id: (Available since v1.242.0) The region ID of the File System.
        :param pulumi.Input[builtins.int] space_capacity: File system capacity.  When the actual amount of data stored reaches the capacity of the file system, data cannot be written.  Unit: GiB.
        :param pulumi.Input[builtins.str] storage_set_name: Save set identity, used to select a user-specified save set.
        :param pulumi.Input[builtins.str] storage_type: The storage media type. Value: STANDARD (default): STANDARD PERFORMANCE: PERFORMANCE type.
        :param pulumi.Input[builtins.str] throughput_mode: The throughput mode. Value: Standard (default): Standard throughput Provisioned: preset throughput.
        :param pulumi.Input[builtins.str] zone_id: Zone Id, which is used to create file system resources to the specified zone.
        """
        if create_time is not None:
            pulumi.set(__self__, "create_time", create_time)
        if data_redundancy_type is not None:
            pulumi.set(__self__, "data_redundancy_type", data_redundancy_type)
        if dedicated_cluster_id is not None:
            pulumi.set(__self__, "dedicated_cluster_id", dedicated_cluster_id)
        if description is not None:
            pulumi.set(__self__, "description", description)
        if file_system_name is not None:
            pulumi.set(__self__, "file_system_name", file_system_name)
        if partition_number is not None:
            pulumi.set(__self__, "partition_number", partition_number)
        if protocol_type is not None:
            pulumi.set(__self__, "protocol_type", protocol_type)
        if provisioned_throughput_in_mi_bps is not None:
            pulumi.set(__self__, "provisioned_throughput_in_mi_bps", provisioned_throughput_in_mi_bps)
        if region_id is not None:
            pulumi.set(__self__, "region_id", region_id)
        if space_capacity is not None:
            pulumi.set(__self__, "space_capacity", space_capacity)
        if storage_set_name is not None:
            pulumi.set(__self__, "storage_set_name", storage_set_name)
        if storage_type is not None:
            pulumi.set(__self__, "storage_type", storage_type)
        if throughput_mode is not None:
            pulumi.set(__self__, "throughput_mode", throughput_mode)
        if zone_id is not None:
            pulumi.set(__self__, "zone_id", zone_id)

    @property
    @pulumi.getter(name="createTime")
    def create_time(self) -> Optional[pulumi.Input[builtins.str]]:
        """
        The creation time of the file system instance.
        """
        return pulumi.get(self, "create_time")

    @create_time.setter
    def create_time(self, value: Optional[pulumi.Input[builtins.str]]):
        pulumi.set(self, "create_time", value)

    @property
    @pulumi.getter(name="dataRedundancyType")
    def data_redundancy_type(self) -> Optional[pulumi.Input[builtins.str]]:
        """
        Redundancy mode of the file system. Value:
        - LRS (default): Local redundancy.
        - ZRS: Same-City redundancy. When ZRS is selected, zoneId is a string consisting of multiple zones that are expected to be redundant in the same city, for example,  'zoneId1,zoneId2 '.
        """
        return pulumi.get(self, "data_redundancy_type")

    @data_redundancy_type.setter
    def data_redundancy_type(self, value: Optional[pulumi.Input[builtins.str]]):
        pulumi.set(self, "data_redundancy_type", value)

    @property
    @pulumi.getter(name="dedicatedClusterId")
    def dedicated_cluster_id(self) -> Optional[pulumi.Input[builtins.str]]:
        """
        Dedicated cluster id, which is used to support scenarios such as group cloud migration.
        """
        return pulumi.get(self, "dedicated_cluster_id")

    @dedicated_cluster_id.setter
    def dedicated_cluster_id(self, value: Optional[pulumi.Input[builtins.str]]):
        pulumi.set(self, "dedicated_cluster_id", value)

    @property
    @pulumi.getter
    def description(self) -> Optional[pulumi.Input[builtins.str]]:
        """
        The description of the file system resource. No more than 32 characters in length.
        """
        return pulumi.get(self, "description")

    @description.setter
    def description(self, value: Optional[pulumi.Input[builtins.str]]):
        pulumi.set(self, "description", value)

    @property
    @pulumi.getter(name="fileSystemName")
    def file_system_name(self) -> Optional[pulumi.Input[builtins.str]]:
        """
        The file system name. The naming rules are as follows: The length is 6~64 characters. Globally unique and cannot be an empty string. English letters are supported and can contain numbers, underscores (_), and dashes (-).
        """
        return pulumi.get(self, "file_system_name")

    @file_system_name.setter
    def file_system_name(self, value: Optional[pulumi.Input[builtins.str]]):
        pulumi.set(self, "file_system_name", value)

    @property
    @pulumi.getter(name="partitionNumber")
    def partition_number(self) -> Optional[pulumi.Input[builtins.int]]:
        """
        Save set sequence number, the user selects the content of the specified sequence number in the Save set.
        """
        return pulumi.get(self, "partition_number")

    @partition_number.setter
    def partition_number(self, value: Optional[pulumi.Input[builtins.int]]):
        pulumi.set(self, "partition_number", value)

    @property
    @pulumi.getter(name="protocolType")
    def protocol_type(self) -> Optional[pulumi.Input[builtins.str]]:
        """
        The protocol type. Value: `HDFS`, `PANGU`.
        """
        return pulumi.get(self, "protocol_type")

    @protocol_type.setter
    def protocol_type(self, value: Optional[pulumi.Input[builtins.str]]):
        pulumi.set(self, "protocol_type", value)

    @property
    @pulumi.getter(name="provisionedThroughputInMiBps")
    def provisioned_throughput_in_mi_bps(self) -> Optional[pulumi.Input[builtins.int]]:
        """
        Provisioned throughput. This parameter is required when ThroughputMode is set to Provisioned. Unit: MB/s Value range: 1~5120.
        """
        return pulumi.get(self, "provisioned_throughput_in_mi_bps")

    @provisioned_throughput_in_mi_bps.setter
    def provisioned_throughput_in_mi_bps(self, value: Optional[pulumi.Input[builtins.int]]):
        pulumi.set(self, "provisioned_throughput_in_mi_bps", value)

    @property
    @pulumi.getter(name="regionId")
    def region_id(self) -> Optional[pulumi.Input[builtins.str]]:
        """
        (Available since v1.242.0) The region ID of the File System.
        """
        return pulumi.get(self, "region_id")

    @region_id.setter
    def region_id(self, value: Optional[pulumi.Input[builtins.str]]):
        pulumi.set(self, "region_id", value)

    @property
    @pulumi.getter(name="spaceCapacity")
    def space_capacity(self) -> Optional[pulumi.Input[builtins.int]]:
        """
        File system capacity.  When the actual amount of data stored reaches the capacity of the file system, data cannot be written.  Unit: GiB.
        """
        return pulumi.get(self, "space_capacity")

    @space_capacity.setter
    def space_capacity(self, value: Optional[pulumi.Input[builtins.int]]):
        pulumi.set(self, "space_capacity", value)

    @property
    @pulumi.getter(name="storageSetName")
    def storage_set_name(self) -> Optional[pulumi.Input[builtins.str]]:
        """
        Save set identity, used to select a user-specified save set.
        """
        return pulumi.get(self, "storage_set_name")

    @storage_set_name.setter
    def storage_set_name(self, value: Optional[pulumi.Input[builtins.str]]):
        pulumi.set(self, "storage_set_name", value)

    @property
    @pulumi.getter(name="storageType")
    def storage_type(self) -> Optional[pulumi.Input[builtins.str]]:
        """
        The storage media type. Value: STANDARD (default): STANDARD PERFORMANCE: PERFORMANCE type.
        """
        return pulumi.get(self, "storage_type")

    @storage_type.setter
    def storage_type(self, value: Optional[pulumi.Input[builtins.str]]):
        pulumi.set(self, "storage_type", value)

    @property
    @pulumi.getter(name="throughputMode")
    def throughput_mode(self) -> Optional[pulumi.Input[builtins.str]]:
        """
        The throughput mode. Value: Standard (default): Standard throughput Provisioned: preset throughput.
        """
        return pulumi.get(self, "throughput_mode")

    @throughput_mode.setter
    def throughput_mode(self, value: Optional[pulumi.Input[builtins.str]]):
        pulumi.set(self, "throughput_mode", value)

    @property
    @pulumi.getter(name="zoneId")
    def zone_id(self) -> Optional[pulumi.Input[builtins.str]]:
        """
        Zone Id, which is used to create file system resources to the specified zone.
        """
        return pulumi.get(self, "zone_id")

    @zone_id.setter
    def zone_id(self, value: Optional[pulumi.Input[builtins.str]]):
        pulumi.set(self, "zone_id", value)


@pulumi.type_token("alicloud:dfs/fileSystem:FileSystem")
class FileSystem(pulumi.CustomResource):
    @overload
    def __init__(__self__,
                 resource_name: str,
                 opts: Optional[pulumi.ResourceOptions] = None,
                 data_redundancy_type: Optional[pulumi.Input[builtins.str]] = None,
                 dedicated_cluster_id: Optional[pulumi.Input[builtins.str]] = None,
                 description: Optional[pulumi.Input[builtins.str]] = None,
                 file_system_name: Optional[pulumi.Input[builtins.str]] = None,
                 partition_number: Optional[pulumi.Input[builtins.int]] = None,
                 protocol_type: Optional[pulumi.Input[builtins.str]] = None,
                 provisioned_throughput_in_mi_bps: Optional[pulumi.Input[builtins.int]] = None,
                 space_capacity: Optional[pulumi.Input[builtins.int]] = None,
                 storage_set_name: Optional[pulumi.Input[builtins.str]] = None,
                 storage_type: Optional[pulumi.Input[builtins.str]] = None,
                 throughput_mode: Optional[pulumi.Input[builtins.str]] = None,
                 zone_id: Optional[pulumi.Input[builtins.str]] = None,
                 __props__=None):
        """
        Provides a Apsara File Storage for HDFS (DFS) File System resource.

        For information about Apsara File Storage for HDFS (DFS) File System and how to use it, see [What is File System](https://www.alibabacloud.com/help/en/aibaba-cloud-storage-services/latest/apsara-file-storage-for-hdfs).

        > **NOTE:** Available since v1.140.0.

        ## Example Usage

        Basic Usage

        ```python
        import pulumi
        import pulumi_alicloud as alicloud

        config = pulumi.Config()
        name = config.get("name")
        if name is None:
            name = "tf-example"
        default = alicloud.dfs.FileSystem("default",
            storage_type="PERFORMANCE",
            zone_id="cn-hangzhou-b",
            protocol_type="PANGU",
            description=name,
            file_system_name=name,
            throughput_mode="Provisioned",
            space_capacity=1024,
            provisioned_throughput_in_mi_bps=512)
        ```

        ## Import

        Apsara File Storage for HDFS (DFS) File System can be imported using the id, e.g.

        ```sh
        $ pulumi import alicloud:dfs/fileSystem:FileSystem example <id>
        ```

        :param str resource_name: The name of the resource.
        :param pulumi.ResourceOptions opts: Options for the resource.
        :param pulumi.Input[builtins.str] data_redundancy_type: Redundancy mode of the file system. Value:
               - LRS (default): Local redundancy.
               - ZRS: Same-City redundancy. When ZRS is selected, zoneId is a string consisting of multiple zones that are expected to be redundant in the same city, for example,  'zoneId1,zoneId2 '.
        :param pulumi.Input[builtins.str] dedicated_cluster_id: Dedicated cluster id, which is used to support scenarios such as group cloud migration.
        :param pulumi.Input[builtins.str] description: The description of the file system resource. No more than 32 characters in length.
        :param pulumi.Input[builtins.str] file_system_name: The file system name. The naming rules are as follows: The length is 6~64 characters. Globally unique and cannot be an empty string. English letters are supported and can contain numbers, underscores (_), and dashes (-).
        :param pulumi.Input[builtins.int] partition_number: Save set sequence number, the user selects the content of the specified sequence number in the Save set.
        :param pulumi.Input[builtins.str] protocol_type: The protocol type. Value: `HDFS`, `PANGU`.
        :param pulumi.Input[builtins.int] provisioned_throughput_in_mi_bps: Provisioned throughput. This parameter is required when ThroughputMode is set to Provisioned. Unit: MB/s Value range: 1~5120.
        :param pulumi.Input[builtins.int] space_capacity: File system capacity.  When the actual amount of data stored reaches the capacity of the file system, data cannot be written.  Unit: GiB.
        :param pulumi.Input[builtins.str] storage_set_name: Save set identity, used to select a user-specified save set.
        :param pulumi.Input[builtins.str] storage_type: The storage media type. Value: STANDARD (default): STANDARD PERFORMANCE: PERFORMANCE type.
        :param pulumi.Input[builtins.str] throughput_mode: The throughput mode. Value: Standard (default): Standard throughput Provisioned: preset throughput.
        :param pulumi.Input[builtins.str] zone_id: Zone Id, which is used to create file system resources to the specified zone.
        """
        ...
    @overload
    def __init__(__self__,
                 resource_name: str,
                 args: FileSystemArgs,
                 opts: Optional[pulumi.ResourceOptions] = None):
        """
        Provides a Apsara File Storage for HDFS (DFS) File System resource.

        For information about Apsara File Storage for HDFS (DFS) File System and how to use it, see [What is File System](https://www.alibabacloud.com/help/en/aibaba-cloud-storage-services/latest/apsara-file-storage-for-hdfs).

        > **NOTE:** Available since v1.140.0.

        ## Example Usage

        Basic Usage

        ```python
        import pulumi
        import pulumi_alicloud as alicloud

        config = pulumi.Config()
        name = config.get("name")
        if name is None:
            name = "tf-example"
        default = alicloud.dfs.FileSystem("default",
            storage_type="PERFORMANCE",
            zone_id="cn-hangzhou-b",
            protocol_type="PANGU",
            description=name,
            file_system_name=name,
            throughput_mode="Provisioned",
            space_capacity=1024,
            provisioned_throughput_in_mi_bps=512)
        ```

        ## Import

        Apsara File Storage for HDFS (DFS) File System can be imported using the id, e.g.

        ```sh
        $ pulumi import alicloud:dfs/fileSystem:FileSystem example <id>
        ```

        :param str resource_name: The name of the resource.
        :param FileSystemArgs args: The arguments to use to populate this resource's properties.
        :param pulumi.ResourceOptions opts: Options for the resource.
        """
        ...
    def __init__(__self__, resource_name: str, *args, **kwargs):
        resource_args, opts = _utilities.get_resource_args_opts(FileSystemArgs, pulumi.ResourceOptions, *args, **kwargs)
        if resource_args is not None:
            __self__._internal_init(resource_name, opts, **resource_args.__dict__)
        else:
            __self__._internal_init(resource_name, *args, **kwargs)

    def _internal_init(__self__,
                 resource_name: str,
                 opts: Optional[pulumi.ResourceOptions] = None,
                 data_redundancy_type: Optional[pulumi.Input[builtins.str]] = None,
                 dedicated_cluster_id: Optional[pulumi.Input[builtins.str]] = None,
                 description: Optional[pulumi.Input[builtins.str]] = None,
                 file_system_name: Optional[pulumi.Input[builtins.str]] = None,
                 partition_number: Optional[pulumi.Input[builtins.int]] = None,
                 protocol_type: Optional[pulumi.Input[builtins.str]] = None,
                 provisioned_throughput_in_mi_bps: Optional[pulumi.Input[builtins.int]] = None,
                 space_capacity: Optional[pulumi.Input[builtins.int]] = None,
                 storage_set_name: Optional[pulumi.Input[builtins.str]] = None,
                 storage_type: Optional[pulumi.Input[builtins.str]] = None,
                 throughput_mode: Optional[pulumi.Input[builtins.str]] = None,
                 zone_id: Optional[pulumi.Input[builtins.str]] = None,
                 __props__=None):
        opts = pulumi.ResourceOptions.merge(_utilities.get_resource_opts_defaults(), opts)
        if not isinstance(opts, pulumi.ResourceOptions):
            raise TypeError('Expected resource options to be a ResourceOptions instance')
        if opts.id is None:
            if __props__ is not None:
                raise TypeError('__props__ is only valid when passed in combination with a valid opts.id to get an existing resource')
            __props__ = FileSystemArgs.__new__(FileSystemArgs)

            __props__.__dict__["data_redundancy_type"] = data_redundancy_type
            __props__.__dict__["dedicated_cluster_id"] = dedicated_cluster_id
            __props__.__dict__["description"] = description
            if file_system_name is None and not opts.urn:
                raise TypeError("Missing required property 'file_system_name'")
            __props__.__dict__["file_system_name"] = file_system_name
            __props__.__dict__["partition_number"] = partition_number
            if protocol_type is None and not opts.urn:
                raise TypeError("Missing required property 'protocol_type'")
            __props__.__dict__["protocol_type"] = protocol_type
            __props__.__dict__["provisioned_throughput_in_mi_bps"] = provisioned_throughput_in_mi_bps
            if space_capacity is None and not opts.urn:
                raise TypeError("Missing required property 'space_capacity'")
            __props__.__dict__["space_capacity"] = space_capacity
            __props__.__dict__["storage_set_name"] = storage_set_name
            if storage_type is None and not opts.urn:
                raise TypeError("Missing required property 'storage_type'")
            __props__.__dict__["storage_type"] = storage_type
            __props__.__dict__["throughput_mode"] = throughput_mode
            __props__.__dict__["zone_id"] = zone_id
            __props__.__dict__["create_time"] = None
            __props__.__dict__["region_id"] = None
        super(FileSystem, __self__).__init__(
            'alicloud:dfs/fileSystem:FileSystem',
            resource_name,
            __props__,
            opts)

    @staticmethod
    def get(resource_name: str,
            id: pulumi.Input[str],
            opts: Optional[pulumi.ResourceOptions] = None,
            create_time: Optional[pulumi.Input[builtins.str]] = None,
            data_redundancy_type: Optional[pulumi.Input[builtins.str]] = None,
            dedicated_cluster_id: Optional[pulumi.Input[builtins.str]] = None,
            description: Optional[pulumi.Input[builtins.str]] = None,
            file_system_name: Optional[pulumi.Input[builtins.str]] = None,
            partition_number: Optional[pulumi.Input[builtins.int]] = None,
            protocol_type: Optional[pulumi.Input[builtins.str]] = None,
            provisioned_throughput_in_mi_bps: Optional[pulumi.Input[builtins.int]] = None,
            region_id: Optional[pulumi.Input[builtins.str]] = None,
            space_capacity: Optional[pulumi.Input[builtins.int]] = None,
            storage_set_name: Optional[pulumi.Input[builtins.str]] = None,
            storage_type: Optional[pulumi.Input[builtins.str]] = None,
            throughput_mode: Optional[pulumi.Input[builtins.str]] = None,
            zone_id: Optional[pulumi.Input[builtins.str]] = None) -> 'FileSystem':
        """
        Get an existing FileSystem resource's state with the given name, id, and optional extra
        properties used to qualify the lookup.

        :param str resource_name: The unique name of the resulting resource.
        :param pulumi.Input[str] id: The unique provider ID of the resource to lookup.
        :param pulumi.ResourceOptions opts: Options for the resource.
        :param pulumi.Input[builtins.str] create_time: The creation time of the file system instance.
        :param pulumi.Input[builtins.str] data_redundancy_type: Redundancy mode of the file system. Value:
               - LRS (default): Local redundancy.
               - ZRS: Same-City redundancy. When ZRS is selected, zoneId is a string consisting of multiple zones that are expected to be redundant in the same city, for example,  'zoneId1,zoneId2 '.
        :param pulumi.Input[builtins.str] dedicated_cluster_id: Dedicated cluster id, which is used to support scenarios such as group cloud migration.
        :param pulumi.Input[builtins.str] description: The description of the file system resource. No more than 32 characters in length.
        :param pulumi.Input[builtins.str] file_system_name: The file system name. The naming rules are as follows: The length is 6~64 characters. Globally unique and cannot be an empty string. English letters are supported and can contain numbers, underscores (_), and dashes (-).
        :param pulumi.Input[builtins.int] partition_number: Save set sequence number, the user selects the content of the specified sequence number in the Save set.
        :param pulumi.Input[builtins.str] protocol_type: The protocol type. Value: `HDFS`, `PANGU`.
        :param pulumi.Input[builtins.int] provisioned_throughput_in_mi_bps: Provisioned throughput. This parameter is required when ThroughputMode is set to Provisioned. Unit: MB/s Value range: 1~5120.
        :param pulumi.Input[builtins.str] region_id: (Available since v1.242.0) The region ID of the File System.
        :param pulumi.Input[builtins.int] space_capacity: File system capacity.  When the actual amount of data stored reaches the capacity of the file system, data cannot be written.  Unit: GiB.
        :param pulumi.Input[builtins.str] storage_set_name: Save set identity, used to select a user-specified save set.
        :param pulumi.Input[builtins.str] storage_type: The storage media type. Value: STANDARD (default): STANDARD PERFORMANCE: PERFORMANCE type.
        :param pulumi.Input[builtins.str] throughput_mode: The throughput mode. Value: Standard (default): Standard throughput Provisioned: preset throughput.
        :param pulumi.Input[builtins.str] zone_id: Zone Id, which is used to create file system resources to the specified zone.
        """
        opts = pulumi.ResourceOptions.merge(opts, pulumi.ResourceOptions(id=id))

        __props__ = _FileSystemState.__new__(_FileSystemState)

        __props__.__dict__["create_time"] = create_time
        __props__.__dict__["data_redundancy_type"] = data_redundancy_type
        __props__.__dict__["dedicated_cluster_id"] = dedicated_cluster_id
        __props__.__dict__["description"] = description
        __props__.__dict__["file_system_name"] = file_system_name
        __props__.__dict__["partition_number"] = partition_number
        __props__.__dict__["protocol_type"] = protocol_type
        __props__.__dict__["provisioned_throughput_in_mi_bps"] = provisioned_throughput_in_mi_bps
        __props__.__dict__["region_id"] = region_id
        __props__.__dict__["space_capacity"] = space_capacity
        __props__.__dict__["storage_set_name"] = storage_set_name
        __props__.__dict__["storage_type"] = storage_type
        __props__.__dict__["throughput_mode"] = throughput_mode
        __props__.__dict__["zone_id"] = zone_id
        return FileSystem(resource_name, opts=opts, __props__=__props__)

    @property
    @pulumi.getter(name="createTime")
    def create_time(self) -> pulumi.Output[builtins.str]:
        """
        The creation time of the file system instance.
        """
        return pulumi.get(self, "create_time")

    @property
    @pulumi.getter(name="dataRedundancyType")
    def data_redundancy_type(self) -> pulumi.Output[Optional[builtins.str]]:
        """
        Redundancy mode of the file system. Value:
        - LRS (default): Local redundancy.
        - ZRS: Same-City redundancy. When ZRS is selected, zoneId is a string consisting of multiple zones that are expected to be redundant in the same city, for example,  'zoneId1,zoneId2 '.
        """
        return pulumi.get(self, "data_redundancy_type")

    @property
    @pulumi.getter(name="dedicatedClusterId")
    def dedicated_cluster_id(self) -> pulumi.Output[Optional[builtins.str]]:
        """
        Dedicated cluster id, which is used to support scenarios such as group cloud migration.
        """
        return pulumi.get(self, "dedicated_cluster_id")

    @property
    @pulumi.getter
    def description(self) -> pulumi.Output[Optional[builtins.str]]:
        """
        The description of the file system resource. No more than 32 characters in length.
        """
        return pulumi.get(self, "description")

    @property
    @pulumi.getter(name="fileSystemName")
    def file_system_name(self) -> pulumi.Output[builtins.str]:
        """
        The file system name. The naming rules are as follows: The length is 6~64 characters. Globally unique and cannot be an empty string. English letters are supported and can contain numbers, underscores (_), and dashes (-).
        """
        return pulumi.get(self, "file_system_name")

    @property
    @pulumi.getter(name="partitionNumber")
    def partition_number(self) -> pulumi.Output[Optional[builtins.int]]:
        """
        Save set sequence number, the user selects the content of the specified sequence number in the Save set.
        """
        return pulumi.get(self, "partition_number")

    @property
    @pulumi.getter(name="protocolType")
    def protocol_type(self) -> pulumi.Output[builtins.str]:
        """
        The protocol type. Value: `HDFS`, `PANGU`.
        """
        return pulumi.get(self, "protocol_type")

    @property
    @pulumi.getter(name="provisionedThroughputInMiBps")
    def provisioned_throughput_in_mi_bps(self) -> pulumi.Output[Optional[builtins.int]]:
        """
        Provisioned throughput. This parameter is required when ThroughputMode is set to Provisioned. Unit: MB/s Value range: 1~5120.
        """
        return pulumi.get(self, "provisioned_throughput_in_mi_bps")

    @property
    @pulumi.getter(name="regionId")
    def region_id(self) -> pulumi.Output[builtins.str]:
        """
        (Available since v1.242.0) The region ID of the File System.
        """
        return pulumi.get(self, "region_id")

    @property
    @pulumi.getter(name="spaceCapacity")
    def space_capacity(self) -> pulumi.Output[builtins.int]:
        """
        File system capacity.  When the actual amount of data stored reaches the capacity of the file system, data cannot be written.  Unit: GiB.
        """
        return pulumi.get(self, "space_capacity")

    @property
    @pulumi.getter(name="storageSetName")
    def storage_set_name(self) -> pulumi.Output[Optional[builtins.str]]:
        """
        Save set identity, used to select a user-specified save set.
        """
        return pulumi.get(self, "storage_set_name")

    @property
    @pulumi.getter(name="storageType")
    def storage_type(self) -> pulumi.Output[builtins.str]:
        """
        The storage media type. Value: STANDARD (default): STANDARD PERFORMANCE: PERFORMANCE type.
        """
        return pulumi.get(self, "storage_type")

    @property
    @pulumi.getter(name="throughputMode")
    def throughput_mode(self) -> pulumi.Output[builtins.str]:
        """
        The throughput mode. Value: Standard (default): Standard throughput Provisioned: preset throughput.
        """
        return pulumi.get(self, "throughput_mode")

    @property
    @pulumi.getter(name="zoneId")
    def zone_id(self) -> pulumi.Output[Optional[builtins.str]]:
        """
        Zone Id, which is used to create file system resources to the specified zone.
        """
        return pulumi.get(self, "zone_id")




# coding=utf-8
# *** WARNING: this file was generated by the Pulumi Terraform Bridge (tfgen) Tool. ***
# *** Do not edit by hand unless you're certain you know what you are doing! ***

import builtins
import copy
import warnings
import sys
import pulumi
import pulumi.runtime
from typing import Any, Mapping, Optional, Sequence, Union, overload
if sys.version_info >= (3, 11):
    from typing import NotRequired, TypedDict, TypeAlias
else:
    from typing_extensions import NotRequired, TypedDict, TypeAlias
from .. import _utilities

__all__ = ['ImagePipelineExecutionArgs', 'ImagePipelineExecution']

@pulumi.input_type
class ImagePipelineExecutionArgs:
    def __init__(__self__, *,
                 image_pipeline_id: pulumi.Input[builtins.str],
                 status: Optional[pulumi.Input[builtins.str]] = None):
        """
        The set of arguments for constructing a ImagePipelineExecution resource.
        :param pulumi.Input[builtins.str] image_pipeline_id: The ID of the image template.
        :param pulumi.Input[builtins.str] status: The status of the image build task. Valid values:
               - CANCELLED: canceled. The build process has been canceled.
        """
        pulumi.set(__self__, "image_pipeline_id", image_pipeline_id)
        if status is not None:
            pulumi.set(__self__, "status", status)

    @property
    @pulumi.getter(name="imagePipelineId")
    def image_pipeline_id(self) -> pulumi.Input[builtins.str]:
        """
        The ID of the image template.
        """
        return pulumi.get(self, "image_pipeline_id")

    @image_pipeline_id.setter
    def image_pipeline_id(self, value: pulumi.Input[builtins.str]):
        pulumi.set(self, "image_pipeline_id", value)

    @property
    @pulumi.getter
    def status(self) -> Optional[pulumi.Input[builtins.str]]:
        """
        The status of the image build task. Valid values:
        - CANCELLED: canceled. The build process has been canceled.
        """
        return pulumi.get(self, "status")

    @status.setter
    def status(self, value: Optional[pulumi.Input[builtins.str]]):
        pulumi.set(self, "status", value)


@pulumi.input_type
class _ImagePipelineExecutionState:
    def __init__(__self__, *,
                 create_time: Optional[pulumi.Input[builtins.str]] = None,
                 image_pipeline_id: Optional[pulumi.Input[builtins.str]] = None,
                 status: Optional[pulumi.Input[builtins.str]] = None):
        """
        Input properties used for looking up and filtering ImagePipelineExecution resources.
        :param pulumi.Input[builtins.str] create_time: The time when the image build task was created.
        :param pulumi.Input[builtins.str] image_pipeline_id: The ID of the image template.
        :param pulumi.Input[builtins.str] status: The status of the image build task. Valid values:
               - CANCELLED: canceled. The build process has been canceled.
        """
        if create_time is not None:
            pulumi.set(__self__, "create_time", create_time)
        if image_pipeline_id is not None:
            pulumi.set(__self__, "image_pipeline_id", image_pipeline_id)
        if status is not None:
            pulumi.set(__self__, "status", status)

    @property
    @pulumi.getter(name="createTime")
    def create_time(self) -> Optional[pulumi.Input[builtins.str]]:
        """
        The time when the image build task was created.
        """
        return pulumi.get(self, "create_time")

    @create_time.setter
    def create_time(self, value: Optional[pulumi.Input[builtins.str]]):
        pulumi.set(self, "create_time", value)

    @property
    @pulumi.getter(name="imagePipelineId")
    def image_pipeline_id(self) -> Optional[pulumi.Input[builtins.str]]:
        """
        The ID of the image template.
        """
        return pulumi.get(self, "image_pipeline_id")

    @image_pipeline_id.setter
    def image_pipeline_id(self, value: Optional[pulumi.Input[builtins.str]]):
        pulumi.set(self, "image_pipeline_id", value)

    @property
    @pulumi.getter
    def status(self) -> Optional[pulumi.Input[builtins.str]]:
        """
        The status of the image build task. Valid values:
        - CANCELLED: canceled. The build process has been canceled.
        """
        return pulumi.get(self, "status")

    @status.setter
    def status(self, value: Optional[pulumi.Input[builtins.str]]):
        pulumi.set(self, "status", value)


@pulumi.type_token("alicloud:ecs/imagePipelineExecution:ImagePipelineExecution")
class ImagePipelineExecution(pulumi.CustomResource):
    @overload
    def __init__(__self__,
                 resource_name: str,
                 opts: Optional[pulumi.ResourceOptions] = None,
                 image_pipeline_id: Optional[pulumi.Input[builtins.str]] = None,
                 status: Optional[pulumi.Input[builtins.str]] = None,
                 __props__=None):
        """
        ## Import

        ECS Image Pipeline Execution can be imported using the id, e.g.

        ```sh
        $ pulumi import alicloud:ecs/imagePipelineExecution:ImagePipelineExecution example <id>
        ```

        :param str resource_name: The name of the resource.
        :param pulumi.ResourceOptions opts: Options for the resource.
        :param pulumi.Input[builtins.str] image_pipeline_id: The ID of the image template.
        :param pulumi.Input[builtins.str] status: The status of the image build task. Valid values:
               - CANCELLED: canceled. The build process has been canceled.
        """
        ...
    @overload
    def __init__(__self__,
                 resource_name: str,
                 args: ImagePipelineExecutionArgs,
                 opts: Optional[pulumi.ResourceOptions] = None):
        """
        ## Import

        ECS Image Pipeline Execution can be imported using the id, e.g.

        ```sh
        $ pulumi import alicloud:ecs/imagePipelineExecution:ImagePipelineExecution example <id>
        ```

        :param str resource_name: The name of the resource.
        :param ImagePipelineExecutionArgs args: The arguments to use to populate this resource's properties.
        :param pulumi.ResourceOptions opts: Options for the resource.
        """
        ...
    def __init__(__self__, resource_name: str, *args, **kwargs):
        resource_args, opts = _utilities.get_resource_args_opts(ImagePipelineExecutionArgs, pulumi.ResourceOptions, *args, **kwargs)
        if resource_args is not None:
            __self__._internal_init(resource_name, opts, **resource_args.__dict__)
        else:
            __self__._internal_init(resource_name, *args, **kwargs)

    def _internal_init(__self__,
                 resource_name: str,
                 opts: Optional[pulumi.ResourceOptions] = None,
                 image_pipeline_id: Optional[pulumi.Input[builtins.str]] = None,
                 status: Optional[pulumi.Input[builtins.str]] = None,
                 __props__=None):
        opts = pulumi.ResourceOptions.merge(_utilities.get_resource_opts_defaults(), opts)
        if not isinstance(opts, pulumi.ResourceOptions):
            raise TypeError('Expected resource options to be a ResourceOptions instance')
        if opts.id is None:
            if __props__ is not None:
                raise TypeError('__props__ is only valid when passed in combination with a valid opts.id to get an existing resource')
            __props__ = ImagePipelineExecutionArgs.__new__(ImagePipelineExecutionArgs)

            if image_pipeline_id is None and not opts.urn:
                raise TypeError("Missing required property 'image_pipeline_id'")
            __props__.__dict__["image_pipeline_id"] = image_pipeline_id
            __props__.__dict__["status"] = status
            __props__.__dict__["create_time"] = None
        super(ImagePipelineExecution, __self__).__init__(
            'alicloud:ecs/imagePipelineExecution:ImagePipelineExecution',
            resource_name,
            __props__,
            opts)

    @staticmethod
    def get(resource_name: str,
            id: pulumi.Input[str],
            opts: Optional[pulumi.ResourceOptions] = None,
            create_time: Optional[pulumi.Input[builtins.str]] = None,
            image_pipeline_id: Optional[pulumi.Input[builtins.str]] = None,
            status: Optional[pulumi.Input[builtins.str]] = None) -> 'ImagePipelineExecution':
        """
        Get an existing ImagePipelineExecution resource's state with the given name, id, and optional extra
        properties used to qualify the lookup.

        :param str resource_name: The unique name of the resulting resource.
        :param pulumi.Input[str] id: The unique provider ID of the resource to lookup.
        :param pulumi.ResourceOptions opts: Options for the resource.
        :param pulumi.Input[builtins.str] create_time: The time when the image build task was created.
        :param pulumi.Input[builtins.str] image_pipeline_id: The ID of the image template.
        :param pulumi.Input[builtins.str] status: The status of the image build task. Valid values:
               - CANCELLED: canceled. The build process has been canceled.
        """
        opts = pulumi.ResourceOptions.merge(opts, pulumi.ResourceOptions(id=id))

        __props__ = _ImagePipelineExecutionState.__new__(_ImagePipelineExecutionState)

        __props__.__dict__["create_time"] = create_time
        __props__.__dict__["image_pipeline_id"] = image_pipeline_id
        __props__.__dict__["status"] = status
        return ImagePipelineExecution(resource_name, opts=opts, __props__=__props__)

    @property
    @pulumi.getter(name="createTime")
    def create_time(self) -> pulumi.Output[builtins.str]:
        """
        The time when the image build task was created.
        """
        return pulumi.get(self, "create_time")

    @property
    @pulumi.getter(name="imagePipelineId")
    def image_pipeline_id(self) -> pulumi.Output[builtins.str]:
        """
        The ID of the image template.
        """
        return pulumi.get(self, "image_pipeline_id")

    @property
    @pulumi.getter
    def status(self) -> pulumi.Output[builtins.str]:
        """
        The status of the image build task. Valid values:
        - CANCELLED: canceled. The build process has been canceled.
        """
        return pulumi.get(self, "status")

